<?php
add_action('after_setup_theme', 'kopa_front_after_setup_theme');

function kopa_front_after_setup_theme() {
    add_theme_support('post-formats', array('gallery', 'audio', 'video'));
    add_theme_support('post-thumbnails');
    add_theme_support('loop-pagination');
    add_theme_support('automatic-feed-links');
    add_theme_support('editor_style');
    add_editor_style('editor-style.css');


    register_nav_menus(array(
        'top-nav' => __('Top Menu', kopa_get_domain()),
        'main-nav' => __('Main Menu', kopa_get_domain()),
        'footer-nav' => __('Footer Menu', kopa_get_domain())
    ));

    if (!is_admin()) {
        add_filter('wp_title', 'kopa_wp_title', 10, 2);
        add_filter('widget_text', 'do_shortcode');
        add_action('wp_enqueue_scripts', 'kopa_front_enqueue_scripts');
        add_filter('body_class', 'kopa_body_class');
        add_action('wp_head', 'kopa_head');
        add_action('wp_footer', 'kopa_foot');
        add_filter('get_the_excerpt','kopa_excerpt');
    } else {
        add_action('show_user_profile', 'kopa_edit_user_profile');
        add_action('edit_user_profile', 'kopa_edit_user_profile');
        add_action('personal_options_update', 'kopa_edit_user_profile_update');
        add_action('edit_user_profile_update', 'kopa_edit_user_profile_update');

    }
    $sizes = array(
        'kopa-size-01'    => array(799, 440, true, __('kopa size 799 x 440 (Kopatheme)', kopa_get_domain())),
        'kopa-size-02'    => array(799, 514, true, __('kopa size 799 x 514 (Kopatheme)', kopa_get_domain())),
        'kopa-size-13'    => array(185, 202, true, __('kopa size 185 x 202 (Kopatheme)', kopa_get_domain())),
        'kopa-size-14'    => array(83, 70, true, __('kopa size 83 x 70 (Kopatheme)', kopa_get_domain())),
        'kopa-size-15'    => array(118, 118, true, __('kopa size 118 x 118 (Kopatheme)', kopa_get_domain())),
        'kopa-size-28'    => array(594, 342, true, __('kopa size 594 x 342 (Kopatheme)', kopa_get_domain())),
        'kopa-size-29'    => array(185, 78, true, __('kopa size 185 x 78 (Kopatheme)', kopa_get_domain())),
        'kopa-size-30'    => array(281, 208, true, __('kopa size 281 x 208 (Kopatheme)', kopa_get_domain())),
        'kopa-size-31'    => array(231, 134, true, __('kopa size 231 x 134 (Kopatheme)', kopa_get_domain())) ,
        'kopa-size-32'    => array(252, 140, true, __('kopa size 252 x 140 (Kopatheme)', kopa_get_domain()))
    );

    apply_filters('kopa_get_image_sizes', $sizes);

    foreach ($sizes as $slug => $details) {
        add_image_size($slug, $details[0], $details[1], $details[2]);
    }

    global $content_width;
    if (!isset($content_width))
        $content_width = 806;
}

/**
 * Create a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @package Resolution
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function kopa_wp_title($title, $sep) {
    global $paged, $page;

    if (is_feed()) {
        return $title;
    }

    // Add the site name.
    $title .= get_bloginfo('name');

    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && ( is_home() || is_front_page() )) {
        $title = "$title $sep $site_description";
    }

    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2) {
        $title = "$title $sep " . sprintf(__('Page %s', kopa_get_domain()), max($paged, $page));
    }

    return $title;
}

function kopa_front_enqueue_scripts() {
    if (!is_admin()) {
        global $wp_styles, $is_IE;

        $dir = get_template_directory_uri();
        /* STYLESHEETs */
        wp_enqueue_style('kopa-google-font', 'http://fonts.googleapis.com/css?family=Oswald:400,300,700', array(), NULL);
        wp_enqueue_style('kopa-font-awesome', $dir . '/css/font-awesome.css');
        wp_enqueue_style('kopa-owl.carousel', $dir . '/css/owl.carousel.css');
        wp_enqueue_style('kopa-jquery-ui', $dir . '/css/jquery-ui.css');
        wp_enqueue_style('kopa-reset', $dir . '/css/reset.css');
        wp_enqueue_style('kopa-grid', $dir . '/css/grid.css');
        wp_enqueue_style('kopa-superfish', $dir . '/css/superfish.css');
        wp_enqueue_style('kopa-bxslider', $dir . '/css/bxslider.css');
        wp_enqueue_style('kopa-navgoco', $dir . '/css/navgoco.css');
        wp_enqueue_style('kopa-extra', $dir . '/css/extra.css');
        wp_enqueue_style('kopa-style', get_stylesheet_uri());

        // enable/disable responsive layout
        if ( 'enable' === kopa_get_option( 'kopa_theme_options_responsive_status', 'enable' ) ) {
            wp_enqueue_style('kopa-responsive', $dir . '/css/responsive.css');
        }

        if ($is_IE) {
            wp_register_style('kopa-ie', $dir . '/css/ie.css', array(), NULL);
            $wp_styles->add_data('kopa-ie', 'conditional', 'lt IE 9');
            wp_enqueue_style('kopa-ie');
        }
        /* JAVASCRIPTs */
        wp_enqueue_script('modernizr.custom', $dir . '/js/modernizr.custom.js', array('jquery'), null);
        wp_localize_script('jquery', 'kopa_front_variable', kopa_front_localize_script());
        wp_enqueue_script('jquery-masonry');
        wp_enqueue_script('hoverIntent');
        wp_enqueue_script( 'jquery-ui-tabs' );

        wp_enqueue_script('kopa-custom-js', $dir . '/js/custom.js', array('jquery'), null, true);
        wp_enqueue_script('set-view-count', $dir . '/js/set-view-count.js', null, null, true);
        if (is_single() || is_page()) {
            wp_enqueue_script('comment-reply');
        }
    }
}

function kopa_front_localize_script() {
    $kopa_variable = array(
        'ajax' => array(
            'url' => admin_url('admin-ajax.php')
        ),
        'template' => array(
            'post_id' => (is_singular()) ? get_queried_object_id() : 0
        ),
        'url' => array(
            'template_directory_uri' => get_template_directory_uri(),
        )
    );
    return $kopa_variable;
}

/* FUNCTION */

function kopa_get_view_count($post_id) {
    $key = 'kopa_' . kopa_get_domain() . '_total_view';
    return kopa_get_post_meta($post_id, $key, true, 'Int');
}

function kopa_set_view_count($post_id) {
    $new_view_count = 0;
    $meta_key = 'kopa_' . kopa_get_domain() . '_total_view';

    $current_views = (int) get_post_meta($post_id, $meta_key, true);

    if ($current_views) {
        $new_view_count = $current_views + 1;
        update_post_meta($post_id, $meta_key, $new_view_count);
    } else {
        $new_view_count = 1;
        add_post_meta($post_id, $meta_key, $new_view_count);
    }
    return $new_view_count;
}

function kopa_breadcrumb() {
    // get show/hide option
    $kopa_breadcrumb_status = kopa_get_option('kopa_theme_options_breadcrumb_status', 'show');

    if ( $kopa_breadcrumb_status != 'show' ) {
        return;
    }

    if (is_main_query()) {
        global $post, $wp_query;

        $prefix = '&nbsp;/&nbsp;';
        $current_class = 'current-page';
        $description = '';
        $breadcrumb_before = '<div class="kopa-breadcrumb">';
        $breadcrumb_after = '</div>';
        $breadcrumb_home = '<span class="kopa-brf">'.__('You are here: ', kopa_get_domain()) .'</span> <span itemscope itemtype="http://data-vocabulary.org/Breadcrumb"><a itemprop="url" href="' . home_url() . '"><span itemprop="title">' . __('Home', kopa_get_domain()) . '</span></a></span>';
        $breadcrumb = '';
        ?>

    <?php
        if (is_home()) {
            $breadcrumb.= $breadcrumb_home;
            if ( get_option( 'page_for_posts' ) ) {
                $breadcrumb.= $prefix . sprintf('<span itemscope itemtype="http://data-vocabulary.org/Breadcrumb" class="%1$s">%2$s</span>', $current_class, get_the_title(get_option('page_for_posts')));
            } else {
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, __('Blog', kopa_get_domain()));
            }
        } else if (is_post_type_archive('product') && get_option('woocommerce_shop_page_id')) {
            $breadcrumb.= $breadcrumb_home;
            $breadcrumb.= $prefix . sprintf('<span itemscope itemtype="http://data-vocabulary.org/Breadcrumb" class="%1$s">%2$s</span>', $current_class, get_the_title(get_option('woocommerce_shop_page_id')));
        } else if (is_tag()) {
            $breadcrumb.= $breadcrumb_home;

            $term = get_term(get_queried_object_id(), 'post_tag');
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $term->name);
        } else if (is_category()) {
            $breadcrumb.= $breadcrumb_home;

            $category_id = get_queried_object_id();
            $terms_link = explode(',', substr(get_category_parents(get_queried_object_id(), TRUE, ','), 0, (strlen(',') * -1)));
            $n = count($terms_link);
            if ($n > 1) {
                for ($i = 0; $i < ($n - 1); $i++) {
                    $breadcrumb.= $prefix . $terms_link[$i];
                }
            }
            $breadcrumb.= $prefix . sprintf('<span class="%1$s" itemprop="title">%2$s</span>', $current_class, get_the_category_by_ID(get_queried_object_id()));

        } else if (is_single()) {
            $breadcrumb.= $breadcrumb_home;

            if ( get_post_type() === 'product' ) :

                $breadcrumb .= $prefix . '<a href="'.get_page_link( get_option('woocommerce_shop_page_id') ).'">'.get_the_title( get_option('woocommerce_shop_page_id') ).'</a>';

                if ($terms = get_the_terms( $post->ID, 'product_cat' )) :
                    $term = apply_filters( 'jigoshop_product_cat_breadcrumb_terms', current($terms), $terms);
                    $parents = array();
                    $parent = $term->parent;
                    while ($parent):
                        $parents[] = $parent;
                        $new_parent = get_term_by( 'id', $parent, 'product_cat');
                        $parent = $new_parent->parent;
                    endwhile;
                    if(!empty($parents)):
                        $parents = array_reverse($parents);
                        foreach ($parents as $parent):
                            $item = get_term_by( 'id', $parent, 'product_cat');
                            $breadcrumb .= $prefix . '<a href="' . get_term_link( $item->slug, 'product_cat' ) . '">' . $item->name . '</a>';
                        endforeach;
                    endif;
                    $breadcrumb .= $prefix . '<a href="' . get_term_link( $term->slug, 'product_cat' ) . '">' . $term->name . '</a>';
                endif;

                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_title());

            else :

                $categories = get_the_category(get_queried_object_id());
                if ($categories) {
                    foreach ($categories as $category) {
                        $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_category_link($category->term_id), $category->name);
                    }
                }

                $post_id = get_queried_object_id();
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_title($post_id));

            endif;

        } else if (is_page()) {
            if (!is_front_page()) {
                $post_id = get_queried_object_id();
                $breadcrumb.= $breadcrumb_home;
                $post_ancestors = get_post_ancestors($post);
                if ($post_ancestors) {
                    $post_ancestors = array_reverse($post_ancestors);
                    foreach ($post_ancestors as $crumb)
                        $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_permalink($crumb), get_the_title($crumb));
                }
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, get_the_title(get_queried_object_id()));
            }
        } else if (is_year() || is_month() || is_day()) {
            $breadcrumb.= $breadcrumb_home;

            $date = array('y' => NULL, 'm' => NULL, 'd' => NULL);

            $date['y'] = get_the_time('Y');
            $date['m'] = get_the_time('m');
            $date['d'] = get_the_time('j');

            if (is_year()) {
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $date['y']);
            }

            if (is_month()) {
                $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_year_link($date['y']), $date['y']);
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, date_i18n('F', $date['m']));
            }

            if (is_day()) {
                $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_year_link($date['y']), $date['y']);
                $breadcrumb.= $prefix . sprintf('<a href="%1$s">%2$s</a>', get_month_link($date['y'], $date['m']), date_i18n('F', $date['m']));
                $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, $date['d']);
            }

        } else if (is_search()) {
            $breadcrumb.= $breadcrumb_home;

            $s = get_search_query();
            $c = $wp_query->found_posts;

            $description = sprintf(__('<span class="%1$s">Your search for "%2$s"', kopa_get_domain()), $current_class, $s);
            $breadcrumb .= $prefix . $description;
        } else if (is_author()) {
            $breadcrumb.= $breadcrumb_home;
            $author_id = get_queried_object_id();
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</a>', $current_class, sprintf(__('Posts created by %1$s', kopa_get_domain()), get_the_author_meta('display_name', $author_id)));
        } else if (is_404()) {
            $breadcrumb.= $breadcrumb_home;
            $breadcrumb.= $prefix . sprintf('<span class="%1$s">%2$s</span>', $current_class, __('Error 404', kopa_get_domain()));
        }

        if ($breadcrumb)
            echo apply_filters('kopa_breadcrumb', $breadcrumb_before . $breadcrumb . $breadcrumb_after);
    }
}

function kopa_get_related_articles() {

    if (is_single()) {
        $get_by = kopa_get_option('kopa_theme_options_post_related_get_by');
        if ('hide' != $get_by) {
            $limit = kopa_get_option('kopa_theme_options_post_related_limit');
            if ($limit > 0) {
                global $post;
                $taxs = array();
                if ('category' == $get_by) {
                    $cats = get_the_category(($post->ID));
                    if ($cats) {
                        $ids = array();
                        foreach ($cats as $cat) {
                            $ids[] = $cat->term_id;
                        }
                        $taxs [] = array(
                            'taxonomy' => 'category',
                            'field' => 'id',
                            'terms' => $ids
                        );
                    }
                } else {
                    $tags = get_the_tags($post->ID);
                    if ($tags) {
                        $ids = array();
                        foreach ($tags as $tag) {
                            $ids[] = $tag->term_id;
                        }
                        $taxs [] = array(
                            'taxonomy' => 'post_tag',
                            'field' => 'id',
                            'terms' => $ids
                        );
                    }
                }

                if ($taxs) {
                    $related_args = array(
                        'tax_query' => $taxs,
                        'post__not_in' => array($post->ID),
                        'posts_per_page' => $limit
                    );
                    $related_posts = new WP_Query($related_args);

                    if ($related_posts->have_posts()) {
                        ?>
                    <div id="related-post">
                        <h4><?php _e('Related Articles', kopa_get_domain()); ?></h4>
                        <div class="list-carousel responsive">
                            <ul class="related-post-carousel">

                                <?php
                                while ($related_posts->have_posts()) {
                                    $related_posts->the_post();
                                    ?>

                                    <li>
                                        <article class="entry-item clearfix">
                                            <div class="entry-thumb">
                                                <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail('kopa-image-size-6'); ?></a>
                                            </div>
                                            <!-- entry-thumb -->
                                            <h6 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h6>
                                        </article>
                                    </li>

                                    <?php } // endwhile  ?>

                            </ul>

                            <div class="clearfix"></div>
                            <div id="pager2" class="carousel-pager clearfix"></div>
                        </div>
                    </div>

                    <?php
                    } // endif
                    wp_reset_postdata();
                }
            }
        }
    }
}

function kopa_get_template_setting() {
    $kopa_setting = kopa_get_option('kopa_setting', unserialize( KOPA_DEFAULT_SETTING ));
    if (is_home()) {
        $setting = $kopa_setting['home'];
    } else if (is_archive()) {
        if (is_category() || is_tag()) {
            $setting = kopa_get_option("kopa_category_setting_" . get_queried_object_id(), $kopa_setting['taxonomy']);
        } else {
            $setting = kopa_get_option("kopa_category_setting_" . get_queried_object_id(), $kopa_setting['archive']);
        }
    } else if (is_singular()) {
        if (is_singular('post')) {
            $setting = kopa_get_option("kopa_post_setting_" . get_queried_object_id(), $kopa_setting['post']);
        } else if (is_page()) {
            $setting = kopa_get_option("kopa_page_setting_" . get_queried_object_id());
            if (!$setting) {
                $setting = $kopa_setting['page'];
            }
        } else {
            $setting = $kopa_setting['post'];
        }
    } else if (is_404()) {
        $setting = $kopa_setting['_404'];
    } else if (is_search()) {
        $setting = $kopa_setting['search'];
    };
    return $setting;
}

function kopa_content_get_gallery($content, $enable_multi = false) {
    return kopa_content_get_media($content, $enable_multi, array('gallery'));
}

function kopa_content_get_audio($content, $enable_multi = false) {
    return kopa_content_get_media($content, $enable_multi, array('audio', 'soundcloud'));
}

function kopa_content_get_media($content, $enable_multi = false, $media_types = array()) {
    $media = array();
    $regex_matches = '';
    $regex_pattern = get_shortcode_regex();
    preg_match_all('/' . $regex_pattern . '/s', $content, $regex_matches);
    foreach ($regex_matches[0] as $shortcode) {
        $regex_matches_new = '';
        preg_match('/' . $regex_pattern . '/s', $shortcode, $regex_matches_new);

        if (in_array($regex_matches_new[2], $media_types)) :
            $media[] = array(
                'shortcode' => $regex_matches_new[0],
                'type' => $regex_matches_new[2],
                'url' => $regex_matches_new[5]
            );
            if (false == $enable_multi) {
                break;
            }
        endif;
    }    return $media;
}

function kopa_content_get_gallery_attachment_ids($content) {
    $gallery = kopa_content_get_gallery($content);

    if (isset($gallery[0])) {
        $gallery = $gallery[0];
    } else {
        return '';
    }

    if (isset($gallery['shortcode'])) {
        $shortcode = $gallery['shortcode'];
    } else {
        return '';
    }

    // get gallery string ids
    preg_match_all('/ids=\"(?:\d+,*)+\"/', $shortcode, $gallery_string_ids);
    if (isset($gallery_string_ids[0][0])) {
        $gallery_string_ids = $gallery_string_ids[0][0];
    } else {
        return '';
    }

    // get array of image id
    preg_match_all('/\d+/', $gallery_string_ids, $gallery_ids);
    if (isset($gallery_ids[0])) {
        $gallery_ids = $gallery_ids[0];
    } else {
        return '';
    }

    return $gallery_ids;
}


class kopa_main_menu extends Walker_Nav_Menu {

    function start_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        $output.= "\n$indent<ul class='sf-sub-menu'>";
    }

}

class kopa_mobile_menu extends Walker_Nav_Menu {

    function start_el(&$output, $item, $depth = 0, $args = array(), $current_object_id = 0) {
        global $wp_query;
        $indent = ( $depth ) ? str_repeat("\t", $depth) : '';

        $class_names = $value = '';

        $classes = empty($item->classes) ? array() : (array) $item->classes;
        $classes[] = 'menu-item-' . $item->ID;

        $class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args));

        if ($depth == 0)
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . ' clearfix"' : 'class="clearfix"';
        else
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : 'class=""';

        $id = apply_filters('nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args);
        $id = $id ? ' id="' . esc_attr($id) . '"' : '';

        $output .= $indent . '<li' . $id . $value . $class_names . '>';

        $attributes = !empty($item->attr_title) ? ' title="' . esc_attr($item->attr_title) . '"' : '';
        $attributes .=!empty($item->target) ? ' target="' . esc_attr($item->target) . '"' : '';
        $attributes .=!empty($item->xfn) ? ' rel="' . esc_attr($item->xfn) . '"' : '';
        $attributes .=!empty($item->url) ? ' href="' . esc_attr($item->url) . '"' : '';
        if ($depth == 0) {
            $item_output = $args->before;
            $item_output .= '<h3><a' . $attributes . '>';
            $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID) . $args->link_after;
            $item_output .= '</a></h3>';
            $item_output .= $args->after;
        } else {
            $item_output = $args->before;
            $item_output .= '<a' . $attributes . '>';
            $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID) . $args->link_after;
            $item_output .= '</a>';
            $item_output .= $args->after;
        }
        $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
    }

    function start_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        if ($depth == 0) {
            $output .= "\n$indent<span>+</span><div class='clearfix'></div><div class='menu-panel clearfix'><ul>";
        } else {
            $output .= '<ul>'; // indent for level 2, 3 ...
        }
    }

    function end_lvl(&$output, $depth = 0, $args = array()) {
        $indent = str_repeat("\t", $depth);
        if ($depth == 0) {
            $output .= "$indent</ul></div>\n";
        } else {
            $output .= '</ul>';
        }
    }

}

function kopa_pagination() {
    global $wp_query, $paged;
    $big = 99999;
    $total_pages = $wp_query->max_num_pages;
    if (!$total_pages)
        $total_pages = 1;
    if (empty($paged))
        $paged = 1;
    if ($total_pages > 1) {
        echo '<div class="pagination clearfix">';
        echo paginate_links(array(
            'base' => str_replace($big, '%#%', esc_url(get_pagenum_link($big))),
            'format' => '?paged=%#%',
            'current' => max(1, get_query_var('paged')),
            'total' => $total_pages,
            'type' => 'list',
            'prev_next' => true,
            'prev_text' => __('Previous', kopa_get_domain()),
            'next_text' => __('Next', kopa_get_domain()),
        ));
        echo '</div>';
    }
}

/**
 * get the id of current post, page
 * @return id of current post, page
 */
function kopa_get_the_ID() {
    $queried_object = get_queried_object();
    return $queried_object->term_id;
}

function kopa_body_class($class) {
    $kopa_setting = kopa_get_template_setting();
    if ($kopa_setting['layout_id'] == 'blog-left-sidebar') {
        $class[] = 'kp-right-sidebar';
    } elseif ($kopa_setting['layout_id'] == 'blog-right-sidebar') {
        $class[] = '';
    } elseif ($kopa_setting['layout_id'] == 'blog-no-sidebar' || $kopa_setting['layout_id'] == '404-page') {
        $class[] = 'kp-no-sidebar';
    }
    if (is_singular()) {
        if (get_post_format() == '') {
            $class[] = 'kp-single-standard';
        } elseif (get_post_format()) {
            $class[] = 'kp-single-' . get_post_format();
        }
    }
    return $class;
}

function kopa_about_author() {
    if ('show' != kopa_get_option('kopa_theme_options_post_about_author', 'show')) {
        return;
    }
    ?>

<div class="kopa-author">
    <div class="widget-content clearfix" itemscope itemtype="http://data-vocabulary.org/Person">
        <div class="author-thumb img-responsive pull-left">
            <a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>"><?php echo get_avatar( get_the_author_meta( 'ID' ), 94 ); ?></a>
        </div>
        <div class="item-right">
            <h4 class="author-title"><span itemprop="name"><?php the_author_posts_link(); ?></span></h4>
            <p><?php the_author_meta( 'description' ); ?></p>
        </div>
    </div>
</div>
<!-- about-author -->
<?php
}

function kopa_edit_user_profile($user) {
    ?>
<h3><?php _e( 'Staff Info', kopa_get_domain() ); ?></h3>
<p><?php _e( 'The information will be displayed in your post about author.', kopa_get_domain() ) ?></p>
<table class="form-table">
    <tr>
        <th><label for="kopa_facebook"><?php _e('Facebook', kopa_get_domain()); ?></label></th>
        <td>
            <input type="url" name="kopa_facebook" id="kopa_facebook" value="<?php echo esc_attr(get_the_author_meta('kopa_facebook', $user->ID)); ?>" class="regular-text" /><br />
            <span class="description"><?php _e('Staff facebook url', kopa_get_domain()); ?></span>
        </td>
    </tr>
    <tr>
        <th><label for="kopa_twitter"><?php _e('Twitter', kopa_get_domain()); ?></label></th>
        <td>
            <input type="url" name="kopa_twitter" id="kopa_twitter" value="<?php echo esc_attr(get_the_author_meta('kopa_twitter', $user->ID)); ?>" class="regular-text" /><br />
            <span class="description"><?php _e('Staff twitter url', kopa_get_domain()); ?></span>
        </td>
    </tr>
    <tr>
        <th><label for="kopa_gplus"><?php _e('Google Plus', kopa_get_domain()); ?></label></th>
        <td>
            <input type="url" name="kopa_gplus" id="kopa_gplus" value="<?php echo esc_attr(get_the_author_meta('kopa_gplus', $user->ID)); ?>" class="regular-text" /><br />
            <span class="description"><?php _e('Staff google plus url', kopa_get_domain()); ?></span>
        </td>
    </tr>
    <tr>
        <th><label for="kopa_linkedin"><?php _e('Linkedin', kopa_get_domain()); ?></label></th>
        <td>
            <input type="url" name="kopa_linkedin" id="kopa_linkedin" value="<?php echo esc_attr(get_the_author_meta('kopa_linkedin', $user->ID)); ?>" class="regular-text" /><br />
            <span class="description"><?php _e('Staff linkedin url', kopa_get_domain()); ?></span>
        </td>
    </tr>
</table>
<?php
}

function kopa_edit_user_profile_update($user_id) {
    if (!current_user_can('edit_user', $user_id)) {
        return false;
    }

    update_user_meta($user_id, 'kopa_facebook', esc_url( $_POST['kopa_facebook'] ) );
    update_user_meta($user_id, 'kopa_twitter', esc_url( $_POST['kopa_twitter'] ) );
    update_user_meta($user_id, 'kopa_gplus', esc_url( $_POST['kopa_gplus'] ) );
    update_user_meta($user_id, 'kopa_linkedin', esc_url( $_POST['kopa_linkedin'] ) );
}

function kopa_excerpt($content){
    if(get_the_title()==''){
        return $content.' ... <a href="'.  get_permalink().'">'. __('Read more',  kopa_get_domain()).' </a>';
    }
    else{
        return $content;
    }
}

function kopa_head() {
    // Logo margin
    $logo_style = '';
    $logo_top_margin = kopa_get_option('kopa_theme_options_logo_margin_top');
    $logo_bottom_margin = kopa_get_option('kopa_theme_options_logo_margin_bottom');
    $logo_left_margin = kopa_get_option('kopa_theme_options_logo_margin_left');
    $logo_right_margin = kopa_get_option('kopa_theme_options_logo_margin_right');
    $logo_margin = '';
    if ($logo_top_margin) {
        $logo_margin.='margin-top:' . $logo_top_margin . 'px!important;';
    }
    if ($logo_bottom_margin) {
        $logo_margin.='margin-bottom:' . $logo_bottom_margin . 'px;';
    }
    if ($logo_left_margin) {
        $logo_margin.='margin-left:' . $logo_left_margin . 'px!important;';
    }
    if ($logo_right_margin) {
        $logo_margin.='margin-right:' . $logo_right_margin . 'px;';
    }
    if ($logo_margin) {
        $logo_style.='#logo-image{' . $logo_margin . ' }';
    }
    echo '<style type="text/css" id="kopa-theme-options-custom-styles">' . $logo_style . '</style>';

    if (kopa_get_option('kopa_theme_options_custom_css')) {
        ?>
    <style type="text/css" id='kopa-user-custom-css'>
            <?php echo kopa_get_option('kopa_theme_options_custom_css'); ?>
    </style>
    <?php
    }
}

function kopa_foot() {
    wp_nonce_field('kopa_change_like_status', 'kopa_change_like_status_wpnonce', false);
    wp_nonce_field('kopa_set_user_rate', 'kopa_set_user_rate_wpnonce', false);
    wp_nonce_field('kopa_set_view_count', 'kopa_set_view_count_wpnonce', false);
}

function kopa_post_navigation() {
    $prev_post = get_previous_post();
    $next_post = get_next_post();
    ?>

<footer class="clearfix">
    <?php if ($prev_post) { ?>
    <p class="prev-post pull-left clearfix">
        <a class="clearfix" href="<?php echo esc_url(get_permalink($prev_post->ID)); ?>"><span class="icon-arrow-left"></span><?php _e('Previous article', kopa_get_domain()); ?></a>
        <a href="<?php echo esc_url(get_permalink($prev_post->ID)); ?>" class="article-title"><?php echo $prev_post->post_title; ?></a>
    </p>
    <?php } ?>

    <?php if ($next_post) { ?>
    <p class="next-post pull-right clearfix">
        <a class="clearfix" href="<?php echo esc_url(get_permalink($next_post->ID)); ?>"><?php _e('Next article', kopa_get_domain()); ?><span class="icon-arrow-right"></span></a>
        <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>" class="article-title"><?php echo $next_post->post_title; ?></a>
    </p>
    <?php } ?>
</footer>

<?php
}
/*
 * header headline
 */
function kopa_get_headline()
{
    $limit = (int) kopa_get_option('kopa_theme_options_headline_limit', 5);
    if ($limit) {
        $prefix = kopa_get_option('kopa_theme_options_headline_prefix', 'HEADLINE');
        $cats = (array)kopa_get_option('kopa_theme_options_headline_cats');
        $cats = implode(',', $cats);

        if( !empty($cats) ){
            $posts = new WP_Query('cat='.$cats.'&posts_per_page='.$limit);
        }else{
            $posts = new WP_Query( 'posts_per_page='.$limit);
        }
        ?>
    <div class="kopa-list-news-carousel-widget">
        <h3 class="widget-title"><?php echo $prefix; ?></h3>
        <div class="kp-headline clearfix">
            <?php
            if ($posts->have_posts()) { ?>
                <div class="kp-headline-wrapper clearfix">
                    <div class="kp-headline clearfix">
                        <dl class="ticker-1 clearfix">
                            <dt style="display: none;">ticket title</dt>
                            <?php
                            while ($posts->have_posts()) {
                                $posts->the_post();
                                $post_url = get_permalink();
                                $post_title = get_the_title();
                                ?>
                                <dd><a href="<?php echo $post_url; ?>" title="<?php echo get_the_title(); ?>"><?php echo $post_title; ?></a></dd>
                                <?php
                            }
                            wp_reset_query();
                            ?>
                        </dl>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
    </div>
    <?php
    }
}

/*
 * get slider
 */
function kopa_slider()
{
    $limit = (int) kopa_get_option('kopa_theme_options_slider_limit', 5);
    if ($limit) {
        $cats =  kopa_get_option('kopa_theme_options_slider_cats');
        if ( !empty($cats)){
            $cats = (array)kopa_get_option('kopa_theme_options_slider_cats');
            $cats = implode(',', $cats);
        }

        if( !empty($cats) ){
            $posts = new WP_Query('cat='.$cats.'&posts_per_page='.$limit.'&ignore_sticky_posts=1');
        }else{
            $posts = new WP_Query( 'posts_per_page='.$limit.'&ignore_sticky_posts=1');
        }
        ?>
            <div class="widget-area-20">
                <div class="widget kopa-thumb-big-carousel-widget">
                    <div class="widget-content">
                        <div class="owl-carousel" data-autoplay="true" data-slidespeed="700">
                            <?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
                            <div class="item">

                                <div class="post-thumb img-responsive">
                                    <?php
                                        if ( has_post_thumbnail()) {
                                            the_post_thumbnail( 'kopa-size-02' );
                                        } else {
                                            echo '<img src="'. get_template_directory_uri() .'/images/slider_no_thumb.gif" alt="' . __('No thumbnail post', kopa_get_domain()) . '" />';
                                        }
                                    ?>

                                </div>

                                <!-- post- thumb -->
                                <div class="item-content">
                                    <?php
                                    $kopa_cats1 = get_the_category(get_the_ID());
                                    if (!empty($kopa_cats1)) :
                                        $count = 0;
                                        ?>
                                        <h4 class="post-cat">
                                            <?php foreach ( $kopa_cats1 as $k => $v) : ?>
                                            <?php if ( $count < 6 && !empty($v->name) ) : ?>
                                                <a href="<?php echo get_category_link($v->term_id); ?>" title="<?php echo $v->name; ?>"><?php echo $v->name; ?></a>
                                                <?php $count++; ?>
                                                <?php endif; ?>
                                            <?php endforeach; ?>
                                        </h4>

                                        <?php endif; ?>

                                    <div class="kopa-metadata">
                                        <?php
                                            $post_title = get_the_title();
                                            if ( empty($post_title) ) {
                                                echo '<a href="'. esc_url(get_permalink()) .'" title="' . __('View post detail', kopa_get_domain()) . '">';
                                            }
                                        ?>
                                        <span class="kopa-date"> <?php the_time(get_option('date_format')); ?></span>
                                        <?php
                                            if ( empty($post_title) ) {
                                                echo '<a href="'. esc_url(get_permalink()) .'">';
                                            }
                                        ?>
                                    </div>
                                    <!-- metadata -->
                                    <h4 class="post-title"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></h4>
                                </div>
                            </div>
                            <!-- item -->
                            <?php endwhile; wp_reset_query();?>
                        </div>
                    </div>
                </div>
            </div>
    <?php
    }
}

/*
 * Kopa get post meta
 */
function kopa_get_post_meta($pid, $key = '', $single = false, $type = 'String', $default = '') {
    $data = get_post_meta($pid, $key, $single);
    switch ($type) {
        case 'Int':
            $data = (int) $data;
            return ($data >= 0) ? $data : $default;
            break;
        default:
            return ($data) ? $data : $default;
            break;
    }
}

/*
 * Kopa check post title is null
 */
function kopa_check_title_null($id){
    $title = get_the_title($id);
    if ( empty($title) )
        return false;

    return true;
}
/*
 * Kopa get time ago
 */
function kopa_print_timeago($field_id, $field_name, $selected_timeago){
    $timeago = array(
        'label' => __('Timestamp (ago)', kopa_get_domain()),
        'options' => array(
            '' => __('-- Select --', kopa_get_domain()),
            '-1 week' => __('1 week', kopa_get_domain()),
            '-2 week' => __('2 weeks', kopa_get_domain()),
            '-3 week' => __('3 weeks', kopa_get_domain()),
            '-1 month' => __('1 months', kopa_get_domain()),
            '-2 month' => __('2 months', kopa_get_domain()),
            '-3 month' => __('3 months', kopa_get_domain()),
            '-4 month' => __('4 months', kopa_get_domain()),
            '-5 month' => __('5 months', kopa_get_domain()),
            '-6 month' => __('6 months', kopa_get_domain()),
            '-7 month' => __('7 months', kopa_get_domain()),
            '-8 month' => __('8 months', kopa_get_domain()),
            '-9 month' => __('9 months', kopa_get_domain()),
            '-10 month' => __('10 months', kopa_get_domain()),
            '-11 month' => __('11 months', kopa_get_domain()),
            '-1 year' => __('1 year', kopa_get_domain()),
            '-2 year' => __('2 years', kopa_get_domain()),
            '-3 year' => __('3 years', kopa_get_domain()),
            '-4 year' => __('4 years', kopa_get_domain()),
            '-5 year' => __('5 years', kopa_get_domain()),
            '-6 year' => __('6 years', kopa_get_domain()),
            '-7 year' => __('7 years', kopa_get_domain()),
            '-8 year' => __('8 years', kopa_get_domain()),
            '-9 year' => __('9 years', kopa_get_domain()),
            '-10 year' => __('10 years', kopa_get_domain()),
        )
    );

    $str_ret = '<p>';
    $str_ret .= '<label for="'.$field_id.'">'. $timeago['label'] . '</label>';
    $str_ret .= '<select class="widefat" name="' . $field_name . '" id="' . $field_id . '">';
    foreach ($timeago['options'] as $k => $v){
        if ($selected_timeago === $k){
            $str_ret .= '<option value="' . $k . '" selected>' . $v . '</option>';
        } else {
            $str_ret .= '<option value="' . $k . '">' . $v . '</option>';
        }

    }
    $str_ret .= '</select>';
    $str_ret .= '</p>';
    echo $str_ret;
}
/*
 * Kopa get category of post id
 */
function kopa_get_categories($id, $many_categories = false) {
    $categories = get_the_category($id);
    if ( empty($categories) ){
        return false;
    }

    if ( $many_categories ) {
        $obj_ret = $categories;
    } else {
        $obj_ret = $categories[0];
    }
    return $obj_ret;
}
/*
 *  Kopa relate articles
 */
function kopa_related_articles() {
    if (is_single()) {
        $get_by = kopa_get_option('kopa_theme_options_post_related_get_by', 'post_tag');
        if ('hide' != $get_by) {
            $limit = (int) kopa_get_option('kopa_theme_options_post_related_limit', 4);
            if ($limit > 0) {
                global $post;
                $taxs = array();
                if ('category' == $get_by) {
                    $cats = get_the_category(($post->ID));
                    if ($cats) {
                        $ids = array();
                        foreach ($cats as $cat) {
                            $ids[] = $cat->term_id;
                        }
                        $taxs [] = array(
                            'taxonomy' => 'category',
                            'field' => 'id',
                            'terms' => $ids
                        );
                    }
                } else {
                    $tags = get_the_tags($post->ID);
                    if ($tags) {
                        $ids = array();
                        foreach ($tags as $tag) {
                            $ids[] = $tag->term_id;
                        }
                        $taxs [] = array(
                            'taxonomy' => 'post_tag',
                            'field' => 'id',
                            'terms' => $ids
                        );
                    }
                }

                if ($taxs) {
                    $related_args = array(
                        'tax_query' => $taxs,
                        'post__not_in' => array($post->ID),
                        'posts_per_page' => $limit
                    );
                    $related_posts = new WP_Query( $related_args );
                    if ( $related_posts->have_posts() ) { ?>

                    <div class="widget kopa-list-posts-carousel-4-widget">
                        <header class="widget-header">
                            <h3 class="widget-title"><?php _e('RELATED ARTICLES', kopa_get_domain()); ?></h3>
                            <i class="fa fa-plus-square-o"></i>
                        </header>
                        <div class="widget-content">
                            <div class="owl-carousel">
                                <?php while ( $related_posts->have_posts() ) : $related_posts->the_post(); $post_title = get_the_title(); ?>
                                <div class="item">
                                    <div class="post-thumb<?php if ( !has_post_thumbnail()) echo ' no-post-thumb'; ?>">
                                        <?php if ( has_post_thumbnail()) : ?>
                                        <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="img-responsive">
                                            <?php the_post_thumbnail('kopa-size-32'); ?>
                                        </a>
                                        <?php endif; ?>

                                        <footer>
                                            <?php
                                            $related_categories = get_the_category(get_the_ID());
                                            $related_category = null;
                                            if( !empty($related_categories) ) {
                                                $related_category = $related_categories[0];
                                            }
                                            ?>
                                            <h4 class="post-cat"><a href="<?php echo get_category_link( $related_category->term_id ); ?>"><?php echo $related_category->name; ?></a></h4>

                                            <?php if ( 'show' === kopa_get_option('kopa_theme_options_view_date_status', 'show') && 'post' === get_post_type() ) :?>
                                            <?php
                                            if ( !empty($post_title)) { ?>
                                                <span class="kopa-date"><?php the_time(get_option('date_format')); ?></span>
                                                <?php }else{?>
                                                <span class="kopa-date"><a href="<?php the_permalink(); ?>" title="<?php _e('View post detail', kopa_get_domain());?>"><?php the_time(get_option('date_format')); ?></a></span>
                                                <?php }
                                            ?>

                                            <?php endif; ?>
                                        </footer>
                                    </div>
                                    <!-- post-thumb -->
                                    <div class="item-content">
                                        <?php

                                        if ( !empty($post_title)) :
                                            ?>
                                            <h4 class="post-title">
                                                <a href="<?php the_permalink(); ?>" title="<?php the_title();?>"><?php the_title(); ?></a>
                                            </h4>
                                            <?php endif; ?>

                                        <div class="kopa-metadata-border">
                                            <?php if ( kopa_get_view_count(get_the_ID()) && kopa_get_option('kopa_theme_options_view_count_status') === 'show') : ?>
                                            <span><i class="fa fa-eye"></i> <?php echo kopa_get_view_count(get_the_ID()); ?></span>
                                            <?php endif; ?>

                                            <?php if ( comments_open() ): ?>
                                            <?php comments_popup_link(__('<i class="fa fa-comment"></i> 0', kopa_get_domain()), __('<i class="fa fa-comment"></i> 1', kopa_get_domain()), __('<i class="fa fa-comment"></i> %', kopa_get_domain()));?>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                    <!-- item content -->
                                </div>
                                <!-- item -->
                                <?php endwhile; ?>
                            </div>
                        </div>
                    </div>

                    <?php
                    } // endif
                    wp_reset_postdata();
                }
            }
        }
    }
}
/*
* Kopa share link posts to socials
*/
function kopa_social_sharing_links() {
    $display_facebook_sharing_button = kopa_get_option('kopa_theme_options_post_sharing_button_facebook', 'show');
    $display_twitter_sharing_button = kopa_get_option('kopa_theme_options_post_sharing_button_twitter', 'show');
    $display_google_sharing_button = kopa_get_option('kopa_theme_options_post_sharing_button_google', 'show');
    $display_linkedin_sharing_button = kopa_get_option('kopa_theme_options_post_sharing_button_linkedin', 'show');
    $display_pinterest_sharing_button = kopa_get_option('kopa_theme_options_post_sharing_button_pinterest', 'show');

    if ( $display_facebook_sharing_button == 'show' ||
        $display_twitter_sharing_button == 'show' ||
        $display_google_sharing_button == 'show' ||
        $display_linkedin_sharing_button  == 'show' ||
        $display_pinterest_sharing_button == 'show' ) :
        ?>

    <div class="link-social-2">

        <?php if ($display_facebook_sharing_button == 'show') :
        $facebook_url =  'https://www.facebook.com/share.php?u=' . get_permalink();
        ?>
        <a href="<?php echo urlencode($facebook_url); ?>" title="Facebook" target="_blank"><i class="fa fa-facebook"></i><?php echo __('&nbsp;&nbsp;Facebook ', kopa_get_domain()); ?></a>
        <?php endif; ?>

        <?php if ($display_twitter_sharing_button == 'show') :
        $twitter_url = 'https://twitter.com/home?status=' . get_the_title().':+' . get_permalink();
        ?>
        <a href="<?php echo urlencode($twitter_url); ?>" title="Twitter" target="_blank"><i class="fa fa-twitter"></i><?php echo __('&nbsp;&nbsp;Twitter ', kopa_get_domain()); ?></a>
        <?php endif; ?>

        <?php if ($display_google_sharing_button == 'show') :
        $gplus_url = 'https://plus.google.com/share?url=' . get_permalink();
        ?>
        <a href="<?php echo urlencode($gplus_url); ?>" title="Google" target="_blank"><i class="fa fa-google-plus"></i><?php echo __('&nbsp;&nbsp;Google +', kopa_get_domain()); ?></a>
        <?php endif; ?>

        <?php if ($display_linkedin_sharing_button == 'show') :
        $linkedin_url = '"http://www.linkedin.com/shareArticle??mini=true&url=' . get_permalink();
        ?>
        <a href="<?php echo urlencode($linkedin_url); ?>" title="Linkedin"><i class="fa fa-linkedin"></i><?php echo __('&nbsp;&nbsp;Linkedin', kopa_get_domain()); ?></a>
        <?php endif; ?>

        <?php if ($display_pinterest_sharing_button == 'show') :
        $pinterest_url = 'http://pinterest.com/pin/create/button/?url=' . get_permalink();
        ?>
        <a href="<?php echo urlencode($pinterest_url); ?>" title="Pinterest"><i class="fa fa-pinterest"></i><?php echo __('&nbsp;&nbsp;Pinterest', kopa_get_domain()); ?></a>
        <?php endif; ?>

    </div>
    <?php
    endif;
}
/*
 * Kopa get client IP
 */
function kopa_get_client_IP() {
    $IP = NULL;

    if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
        //check if IP is from shared Internet
        $IP = $_SERVER['HTTP_CLIENT_IP'];
    } elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
        //check if IP is passed from proxy
        $ip_array = explode(",", $_SERVER['HTTP_X_FORWARDED_FOR']);
        $IP = trim($ip_array[count($ip_array) - 1]);
    } elseif (!empty($_SERVER['REMOTE_ADDR'])) {
        //standard IP check
        $IP = $_SERVER['REMOTE_ADDR'];
    }
    return $IP;
}
/*
 * Kopa get custom date
 */
function kopa_the_date_custom ($post_id = 0, $format = 'Y') {
    $date = date_create(get_post_field( 'post_date', $post_id));
    if ( 'dM' === $format){
        echo $date->format('d').' '.$date->format('M');
    }else{
        echo $date->format($format);
    }
}

/*
 * Kopa get next previous link for current post
 */
function kopa_get_next_previous(){
    $prev_post = get_previous_post();
    $next_post = get_next_post();

    if ( 'show' === kopa_get_option('kopa_theme_options_post_link', 'show') && ( get_next_post() || get_previous_post() ) ) :?>
    <ul class="pager-page list-unstyled clearfix">
        <?php if (!empty( $prev_post )):
        $categories = get_the_category($prev_post->ID);
        $category = null;
        if( !empty($categories) ) {
            $category = $categories[0];
        }

        ?>

        <li class="prev-post pull-left">
            <h4 class="prev"><i class="fa fa-angle-double-left"></i><a href="<?php echo get_permalink( $prev_post->ID ); ?>"><?php echo __('Previous Article', kopa_get_domain());?></a></h4>
            <?php if ( !empty($prev_post->post_title)) : ?>
            <h4 class="post-title"><a href="<?php echo get_permalink( $prev_post->ID ); ?>"><?php echo $prev_post->post_title;?></a></h4>
            <?php endif; ?>
            <span class="kopa-date"><?php echo get_the_time( get_option('date_format'), $prev_post->ID ); ?></span>
            <a href="<?php echo get_category_link( $category->term_id ); ?>" class="post-cat"><?php echo $category->name; ?></a>
        </li>
        <?php endif; ?>

        <?php if (!empty($next_post)) :
        $categories_next = get_the_category($next_post->ID);
        $category_next = null;
        if ( !empty($categories_next) ) {
            $category_next = $categories_next[0];
        }
        ?>
        <li class="next-post pull-right">
            <h4 class="next"><a href="<?php echo get_permalink( $next_post->ID ); ?>"><?php echo __('Next Article', kopa_get_domain());?></a><i class="fa fa-angle-double-right"></i></h4>
            <?php if (!empty($next_post->post_title)) : ?>
            <h4 class="post-title"><a href="<?php echo get_permalink( $next_post->ID ); ?>" title="<?php echo $next_post->post_title;?>"><?php echo $next_post->post_title;?></a></h4>
            <?php endif; ?>

            <?php
            if (!empty($next_post->post_title)){ ?>
                <span class="kopa-date"><?php echo get_the_time( get_option('date_format'), $next_post->ID ); ?></span>
                <?php } else{?>
                <span class="kopa-date"><a href="<?php echo get_permalink( $next_post->ID ); ?>" title="<?php _e('Post no title', kopa_get_domain());?>"><?php echo get_the_time( get_option('date_format'), $next_post->ID ); ?></a></span>
                <?php }
            ?>

            <a href="<?php echo get_category_link( $category_next->term_id ); ?>" class="post-cat"><?php echo $category_next->name; ?></a>
        </li>
        <?php endif; ?>
    </ul>
    <?php endif;
}