<?php
/**
 * Widget Registration
 * @package Karo
 */
add_action('widgets_init', 'kopa_widgets_init');

function kopa_widgets_init() {
    register_widget('Kopa_Widget_Flickr');
    register_widget('Kopa_Widget_Article_Single');
    register_widget('Kopa_Widget_Advertising');
    register_widget('Kopa_Widget_Social_Share');
    register_widget('Kopa_Widget_Feedburner_Subscribe');
    register_widget('Kopa_Widget_Mailchimp_Subscribe');
    register_widget('Kopa_Widget_Articles_List');
    register_widget('Kopa_Widget_Video');
    register_widget('Kopa_Widget_Combo');
    register_widget('Kopa_Widget_List_Gallery');
    register_widget('Kopa_Widget_Single_Gallery');
    register_widget('Kopa_Widget_Tab');
    register_widget('Kopa_Widget_Audio');
    register_widget('Kopa_Widget_Contact_Info');
}

add_action('admin_enqueue_scripts', 'kopa_widget_admin_enqueue_scripts');

function kopa_widget_admin_enqueue_scripts($hook) {
    if ('widgets.php' === $hook) {
        $dir = get_template_directory_uri() . '/library';
        wp_enqueue_style('kopa_widget_admin', "{$dir}/css/widget.css");
        wp_enqueue_script('kopa_widget_admin', "{$dir}/js/widget.js", array('jquery'));
    }
}

function kopa_widget_posttype_build_query( $query_args = array() ) {
    $default_query_args = array(
        'post_type'      => 'post',
        'posts_per_page' => -1,
        'post__not_in'   => array(),
        'ignore_sticky_posts' => 1,
        'categories'     => array(),
        'tags'           => array(),
        'relation'       => 'OR',
        'post_format' => '',
        'orderby'        => 'latest',
        'cat_name'       => 'category',
        'tag_name'       => 'post_tag'
    );

    $query_args = wp_parse_args( $query_args, $default_query_args );

    $args = array(
        'post_type'           => $query_args['post_type'],
        'posts_per_page'      => $query_args['posts_per_page'],
        'post_format' => $query_args['post_format'],
        'post__not_in'        => $query_args['post__not_in'],
        'ignore_sticky_posts' => $query_args['ignore_sticky_posts']
    );

    $tax_query = array();

    if ( $query_args['categories'] ) {
        $tax_query[] = array(
            'taxonomy' => $query_args['cat_name'],
            'field'    => 'id',
            'terms'    => $query_args['categories']
        );
    }
    if ( $query_args['tags'] ) {
        $tax_query[] = array(
            'taxonomy' => $query_args['tag_name'],
            'field'    => 'id',
            'terms'    => $query_args['tags']
        );
    }
    if ( $query_args['relation'] && count( $tax_query ) == 2 ) {
        $tax_query['relation'] = $query_args['relation'];
    }
    if ( $query_args['post_format'] ) {
        $tax_query[] = array(
            'taxonomy' => 'post_format',
            'field' => 'slug',
            'terms' => array( $query_args['post_format'] )
        );
    }

    if ( isset($query_args['date_query']) && $query_args['date_query'] ){
        global $wp_version;
        $timestamp =  $query_args['date_query'];
        if (version_compare($wp_version, '3.7.0', '>=')) {
            if (isset($timestamp) && !empty($timestamp)) {
                $y = date('Y', strtotime($timestamp));
                $m = date('m', strtotime($timestamp));
                $d = date('d', strtotime($timestamp));
                $args['date_query'] = array(
                    array(
                        'after' => array(
                            'year' => (int) $y,
                            'month' => (int) $m,
                            'day' => (int) $d
                        )
                    )
                );
            }
        }
    }


    if ( $tax_query ) {
        $args['tax_query'] = $tax_query;
    }

    switch ( $query_args['orderby'] ) {
        case 'popular':
            $args['meta_key'] = 'kopa_' . kopa_get_domain() . '_total_view';
            $args['orderby'] = 'meta_value_num';
            break;
        case 'most_comment':
            $args['orderby'] = 'comment_count';
            break;
        case 'random':
            $args['orderby'] = 'rand';
            break;
        default:
            $args['orderby'] = 'date';
            break;
    }

    return new WP_Query( $args );
}

/**
 * Advertising widget class
 * User can upload image and enter a link
 */
class Kopa_Widget_Advertising extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-ads-widget', 'description' => __('A widget that displays an advertising image', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_advertising', __('Kopa Advertising Widget', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget( $args, $instance ) {
        extract($args);
        $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

        $target = $instance['target'] ? '_blank' : '_self';

        echo $before_widget;
        if ( !empty( $title ) ) { echo $before_title . $title . $after_title; } ?>
    <div class="widget-content">
        <?php if ( ! empty( $instance['url'] ) ) {
        echo  '<a href="'.$instance['url'].'" target="'.$target.'">';
    } ?>

        <img src="<?php echo $instance['image'];?>" alt="<?php echo $title; ?>">

        <?php if ( ! empty( $instance['url'] ) ) {
        echo '</a>';
    } ?>
    </div>
    <?php
        echo $after_widget;
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['image'] = $new_instance['image'];
        $instance['url'] = esc_url( $new_instance['url'] );
        $instance['target'] = isset( $new_instance['target'] ) ? $new_instance['target'] : null;
        return $instance;
    }

    function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array(
            'title'  => '',
            'image'  => '',
            'url'    => '',
            'target' => null,
        ) );
        $title = strip_tags($instance['title']);
        ?>
    <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>"></p>

    <p class="clearfix">
        <label for="<?php echo $this->get_field_id( 'image' ); ?>"><?php _e( 'Image:', kopa_get_domain() ) ?></label>
        <input class="widefat" type="url" value="<?php echo $instance['image']; ?>" id="<?php echo $this->get_field_id( 'image' ); ?>" name="<?php echo $this->get_field_name( 'image' ); ?>">
        <span>&nbsp;</span>
        <button class="left btn btn-success upload_image_button" alt="<?php echo $this->get_field_id( 'image' ); ?>"><i class="icon-circle-arrow-up"></i><?php _e('Upload', kopa_get_domain()); ?></button>
    </p>

    <p><label for="<?php echo $this->get_field_id( 'url' ); ?>"><?php _e('URL:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" type="text" value="<?php echo esc_attr( $instance['url'] ); ?>"></p>

    <p>
        <input type="checkbox" name="<?php echo $this->get_field_name( 'target' ); ?>" id="<?php echo $this->get_field_id( 'target' ); ?>" <?php checked( $instance['target'], '1' ); ?> value="1">
        <label for="<?php echo $this->get_field_id( 'target' ); ?>"><?php _e( 'Open link in a new tab', kopa_get_domain() ); ?></label>
    </p>

    <?php
    }
}

/**
 * Widget article list
 */
class Kopa_Widget_Articles_List extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kp-article-list-widget', 'description' => __('Article list widget', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_article_list', __('Kopa Widget Article List', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);

        $query_args['categories'] = $instance['categories'];
        $query_args['relation'] = esc_attr($instance['relation']);
        $query_args['tags'] = $instance['tags'];
        $query_args['posts_per_page'] = (int) $instance['posts_per_page'];
        if (isset($instance['kopa_timestamp'])){
            $query_args['date_query'] = $instance['kopa_timestamp'];
        }
        $query_args['orderby'] = $instance['orderby'];
        $posts = kopa_widget_posttype_build_query($query_args);

        ?>
    <div class="widget kopa-list-posts-thumb-medium-widget">
        <header class="widget-header">
            <h3 class="widget-title"><?php echo $title; ?></h3>
            <i class="fa fa-plus-square-o"></i>
        </header>
        <div class="widget-content">
            <?php $i=0;?>
            <?php while ( $posts->have_posts() ) :
                $posts->the_post();
                $post_title = get_the_title();
            ?>
            <div class="item-post<?php if($i%2==0) echo ' clearleft';?>">
                <a href="<?php the_permalink(); ?>" title="<?php the_title();?>" class="post-thumb img-responsive">
                    <?php
                        $post_thumbnail = get_the_post_thumbnail(get_the_ID(), 'kopa-size-13');
                        if ( empty($post_thumbnail) ){
                            $post_thumbnail = get_template_directory_uri().'/images/no-thumbnail.jpg';
                            echo '<img src="'. $post_thumbnail .'" alt="' . get_the_title(get_the_ID()) .'" title="' . get_the_title(get_the_ID()) .'" />';
                        }else{
                            echo $post_thumbnail;
                        }
                    ?>
                    <div class="mask2"></div>
                </a>
                <?php if (!empty($post_title)):?>
                <div class="item-content">
                    <h4 class="post-title"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title();?></a></h4>
                </div>
                <?php endif; ?>
                <!-- item-content -->
            </div>
            <!-- item-post -->
            <?php $i++;?>
            <?php endwhile; ?>
        </div>
    </div>
    <?php
        wp_reset_postdata();
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'categories' => array(),
            'relation' => 'OR',
            'tags' => array(),
            'posts_per_page' => 6,
            'kopa_timestamp' => '',
            'limit' => 55,
            'orderby' => 'latest',
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $limit = (int)$instance['limit'];

        $form['categories'] = $instance['categories'];
        $form['relation'] = esc_attr($instance['relation']);
        $form['tags'] = $instance['tags'];
        $form['posts_per_page'] = (int) $instance['posts_per_page'];
        $form['kopa_timestamp'] = (int) $instance['kopa_timestamp'];
        $form['orderby'] = $instance['orderby'];
        ?>

    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'categories' ); ?>"><?php _e( 'Categories', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'categories' ); ?>" name="<?php echo $this->get_field_name( 'categories' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $categories = get_categories();
            foreach ($categories as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['categories']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('relation'); ?>"><?php _e('Relation', kopa_get_domain()); ?>:</label>
        <select class="widefat" name="<?php echo $this->get_field_name('relation'); ?>" id="<?php echo $this->get_field_id('relation'); ?>">
            <option value="OR" <?php selected('OR', $form['relation']); ?>><?php _e('OR', kopa_get_domain()); ?></option>
            <option value="AND" <?php selected('AND', $form['relation']); ?>><?php _e('AND', kopa_get_domain()); ?></option>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'tags' ); ?>"><?php _e( 'Tags', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'tags' ); ?>" name="<?php echo $this->get_field_name( 'tags' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $tags = get_tags();
            foreach ($tags as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['tags']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <?php kopa_print_timeago($this->get_field_id('kopa_timestamp'), $this->get_field_name('kopa_timestamp'), $form['kopa_timestamp']); ?>
    <p>
        <label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Orderby', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id('orderby' ); ?>">
            <?php $orderby = array(
            'latest'      => __('Latest', kopa_get_domain()),
            'popular'      => __('Popular by view count', kopa_get_domain()),
            'most_comment' => __('Popular by comment count', kopa_get_domain()),
            'random'       => __('Random', kopa_get_domain())
        );

            foreach ($orderby as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['orderby']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('posts_per_page'); ?>"><?php _e('Number of items:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('posts_per_page'); ?>" name="<?php echo $this->get_field_name('posts_per_page'); ?>" value="<?php echo $form['posts_per_page']; ?>" type="number" min="1">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('limit'); ?>"><?php _e('Custom post excerpt length:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('limit'); ?>" name="<?php echo $this->get_field_name('limit'); ?>" type="text" value="<?php echo $limit; ?>" />
    </p>


    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['categories'] = (empty($new_instance['categories'])) ? array() : array_filter($new_instance['categories']);
        $instance['relation'] = $new_instance['relation'];
        $instance['tags'] = (empty($new_instance['tags'])) ? array() : array_filter($new_instance['tags']);
        $instance['posts_per_page'] = (int) $new_instance['posts_per_page'];
        $instance['orderby'] = $new_instance['orderby'];
        $instance['kopa_timestamp'] = $new_instance['kopa_timestamp'];
        $instance['limit'] = $new_instance['limit'];
        return $instance;
    }
}

/**
 * Widget Flickr list
 */
class Kopa_Widget_Flickr extends WP_Widget {
    function __construct(){
        $widget_ops = array('classname' => 'kopa-flickr-widget', 'description' => __('Display list images of user from Flickr API', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_flickr', __('Kopa Widget Flickr', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget($args, $instance){
        extract($args);
        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);

        $id = $instance['user_id'];
        $limit = $instance['limit'];
        $out = '<div class="widget-content">';
        $out .= sprintf('<div class="flickr-wrap clearfix" data-user="%s" data-limit="%s">', $id, $limit);
        $out .= '<ul class="clearfix list-unstyled"></ul>';
        $out .= '</div></div>';
        echo $before_widget;
        if (!empty($title)) { ?>
        <header class="widget-header">
            <h3 class="widget-title"><?php echo $title;?></h3>
            <i class="fa fa-plus-square-o"></i>
        </header>

        <?php }
        echo apply_filters('kopa_flickr_widget', $out);
        echo $after_widget;
    }

    function form($instance){
        $default = array(
            'title' => __( 'Photo On Flickr', kopa_get_domain() ),
            'limit' => 9,
            'user_id' => ''
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $form['limit'] = (int) $instance['limit'];
        $form['user_id'] = $instance['user_id'];

        ?>

    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>

    <p>
        <label for="<?php echo $this->get_field_id('user_id'); ?>"><?php _e('User ID:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('user_id'); ?>" name="<?php echo $this->get_field_name('user_id'); ?>" type="text" value="<?php echo $form['user_id']; ?>" />
    </p>

    <p>
        <label for="<?php echo $this->get_field_id('limit'); ?>"><?php _e('Number of photo:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('limit'); ?>" name="<?php echo $this->get_field_name('limit'); ?>" value="<?php echo $form['limit']; ?>" type="number" min="1">
    </p>

    <?php
    }

    function update($new_instance, $old_instance){
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['user_id'] = $new_instance['user_id'];
        $instance['limit'] = $new_instance['limit'];
        return $instance;
    }
}

/**
 * Gallery Widget Class
 * @since Karo 1.0
 */
class Kopa_Widget_Single_Gallery extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-single-gallery-widget', 'description' => __('List gallery of post', kopa_get_domain()));
        $control_ops = array('width'=>'auto', 'height'=>'auto');
        parent::__construct('kopa_widget_single_gallery', __('Kopa Widget Single Gallery', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'kpgallery' => '',
            'limit' => 55,
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $limit = (int)$instance['limit'];
        $form['kpgallery'] = $instance['kpgallery'];
        $form['limit'] = $instance['limit'];
        ?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('kpgallery'); ?>"><?php echo __('Gallery:', kopa_get_domain()); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id('kpgallery'); ?>" name="<?php echo $this->get_field_name('kpgallery'); ?>"  autocomplete="off">
            <option value=""><?php echo __('-- None --', kopa_get_domain()); ?></option>
            <?php
            $gallery_post = get_posts(array('post_format' => 'post-format-gallery'));

            foreach ($gallery_post as $key => $value):
                printf('<option value="%1$s" %3$s>%2$s </option>', $value->ID, $value->post_title, ($value->ID == $form['kpgallery'] ) ? 'selected="selected"' : '');
            endforeach;
            ?>
        </select>

    </p>
    <p>
        <label for="<?php echo $this->get_field_id('limit'); ?>"><?php _e('Custom post excerpt length. (Enter 0 if you want to show full length):', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('limit'); ?>" name="<?php echo $this->get_field_name('limit'); ?>" type="text" value="<?php echo $limit; ?>" />
    </p>
    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['kpgallery'] = $new_instance['kpgallery'];
        $instance['limit'] = $new_instance['limit'];
        return $instance;
    }

    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
        $gallery = $instance['kpgallery'];
        $limit = $instance['limit'];
        $gal_content_post = get_post($gallery);
        $gal_content = $gal_content_post->post_content;
        $gal_ids = kopa_content_get_gallery_attachment_ids($gal_content);
        ?>


    <?php echo $before_widget;?>
    <header class="widget-header">
        <h3 class="widget-title"><?php echo $title;?></h3>
    </header>

    <div class="widget-content clearfix">
        <div class="owl-carousel sync1">
            <?php
            if(!empty($gal_ids)) {
                foreach ($gal_ids as $id){
                    if (wp_attachment_is_image($id)){?>
                        <div class="item">
                            <a href="#" class="img-responsive">
                                <?php echo wp_get_attachment_image($id, 'kopa-size-28'); ?>
                            </a>
                        </div>
                        <!-- item -->
                        <?php }
                }
            }
            ?>

        </div><!-- sync 1 -->

        <div class="owl-carousel sync2">
            <?php
            if(!empty($gal_ids)) {
                foreach ($gal_ids as $id){
                    if (wp_attachment_is_image($id)){?>
                        <div class="item img-responsive">
                            <?php echo wp_get_attachment_image($id, 'kopa-size-29'); ?>
                        </div>
                        <!-- item -->
                        <?php }
                }
            }
            ?>
        </div><!-- sync 2 -->

        <div class="clearfix"></div>

        <div class="post-content">
            <?php
            $temp_excerp = $gal_content_post->post_excerpt;
            if (empty($gal_content_post->post_excerpt)){
                $temp_excerp = $gal_content;
            }
            $temp_excerp = strip_tags($temp_excerp);
            $temp_excerp = strip_shortcodes($temp_excerp);
            if ( $limit ){
                $the_excerp = wp_trim_words($temp_excerp, $limit, $more = null);
            }else{
                $the_excerp = $temp_excerp;
            }

            ?>
            <p><?php echo $the_excerp; ?></p>
        </div>
        <!-- post content -->
    </div>
    <?php echo $after_widget;?>

    <?php wp_reset_postdata();
    }
}

/**
 * Tab Widget Class
 * @since Karo 1.0
 */
class Kopa_Widget_Tab extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-list-post-tabs-widget', 'description' => __('Display selected categories as tab', kopa_get_domain()));
        $control_ops = array('width'=>'auto', 'height'=>'auto');
        parent::__construct('kopa_widget_tab', __('Kopa Widget Tab', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'categories' => array(),
            'posts_per_page' => 3,
            'kopa_timestamp' => '',
            'orderby' => 'latest'
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $form['categories'] = $instance['categories'];
        $form['posts_per_page'] = (int) $instance['posts_per_page'];
        $form['kopa_timestamp'] = (int) $instance['kopa_timestamp'];
        $form['orderby'] = $instance['orderby'];
        ?>

    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'categories' ); ?>"><?php _e( 'Categories', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'categories' ); ?>" name="<?php echo $this->get_field_name( 'categories' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $categories = get_categories();
            foreach ($categories as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['categories']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <?php kopa_print_timeago($this->get_field_id('kopa_timestamp'), $this->get_field_name('kopa_timestamp'), $form['kopa_timestamp']); ?>
    <p>
        <label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Orderby', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id('orderby' ); ?>">
            <?php $orderby = array(
            'latest'      => __('Latest', kopa_get_domain()),
            'popular'      => __('Popular by view count', kopa_get_domain()),
            'most_comment' => __('Popular by comment count', kopa_get_domain()),
            'random'       => __('Random', kopa_get_domain())
        );

            foreach ($orderby as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['orderby']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('posts_per_page'); ?>"><?php _e('Number of items:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('posts_per_page'); ?>" name="<?php echo $this->get_field_name('posts_per_page'); ?>" value="<?php echo $form['posts_per_page']; ?>" type="number" min="1">
    </p>

    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['categories'] = (empty($new_instance['categories'])) ? array() : array_filter($new_instance['categories']);
        $instance['posts_per_page'] = (int) $new_instance['posts_per_page'];
        $instance['kopa_timestamp'] = $new_instance['kopa_timestamp'];
        $instance['orderby'] = $new_instance['orderby'];
        return $instance;
    }



    function widget($args, $instance) {
        extract($args);
        $aCategories = $instance['categories'];
        echo $before_widget;
        ?>

    <header class="widget-header">
        <h3 class="widget-title"><?php _e('list post tab', kopa_get_domain()); ?></h3>
        <i class="fa fa-plus-square-o"></i>
    </header>

    <div class="widget-content">
        <div class="kopa-tabs">
            <?php if (!empty($aCategories)) : ?>
            <ul>
                <?php $index = 0; ?>
                <?php foreach($aCategories as $v): $index++; ?>

                <li><a href="#tabs<?php echo $this->number;?>-<?php echo $index;?>"><?php echo get_cat_name($v);?></a></li>

                <?php endforeach; ?>
            </ul>

            <?php $index1 = 0;?>
            <?php foreach ($aCategories as $v ) : $index1++; ?>
                <div id="tabs<?php echo $this->number;?>-<?php echo $index1;?>">
                    <?php
                    $args['categories'] = $v;
                    $args['posts_per_page'] = (int) $instance['posts_per_page'];
                    if (isset($instance['kopa_timestamp'])){
                        $args['date_query'] = $instance['kopa_timestamp'];
                    }
                    $posts = kopa_widget_posttype_build_query($args);
                    ?>
                    <div class="masonry-outer">
                        <div class="masonry-content">
                            <?php while ( $posts->have_posts()) :
                                $posts->the_post();
                                $post_title = get_the_title();
                            ?>
                            <div class="item-outer">
                                <div class="item">
                                    <div class="post-thumb<?php if (!has_post_thumbnail()) echo ' no-post-thumb'; ?>">
                                        <?php if (has_post_thumbnail()) : ?>
                                        <a href="<?php the_permalink();?>" class="img-responsive" title="<?php the_title(); ?>">
                                            <?php the_post_thumbnail('kopa-size-30'); ?>
                                        </a>
                                        <?php endif; ?>
                                        <footer>
                                            <?php
                                            $category = kopa_get_categories(get_the_ID());
                                            ?>
                                            <h4 class="post-cat"><a href="<?php echo get_category_link($category->term_id); ?>"><?php echo $category->name; ?></a></h4>
                                            <span class="kopa-date"><?php the_time(get_option('date_format'));?></span>
                                        </footer>
                                    </div>
                                    <?php if (!empty($post_title)) : ?>
                                        <h4 class="post-title">
                                            <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title();?></a>
                                        </h4>
                                    <?php endif; ?>
                                </div>
                                <!-- item -->
                            </div>
                            <!-- item outer -->
                            <?php endwhile; ?>
                            <?php wp_reset_postdata(); ?>
                        </div>
                        <!-- masonry-content -->
                    </div>
                    <!-- masonry outer -->
                </div>
                <?php endforeach; ?>

            <?php endif; ?>
        </div>
    </div>


    <?php echo $args['after_widget'];?>
    <?php
    }
}

/**
 * Sidebar Tab Widget Class
 * @since Karo 1.0
 */
class Kopa_Widget_Combo extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-tab-widget', 'description' => __('A widget displays popular articles, recent articles and most comment articles.', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_combo', __('Kopa Widget Combo', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget( $args, $instance ) {
        extract( $args );
        $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

        echo $before_widget;

        $query_args['posts_per_page'] = $instance['number_of_article'];
        $display_date_meta = $instance['display_date_meta'];
        $tab_args = array();

        if ( $instance['popular_title'] ) {
            $tab_args[] = array(
                'label'   => $instance['popular_title'],
                'orderby' => 'popular',
            );
        }

        if ( $instance['latest_title'] ) {
            $tab_args[] = array(
                'label'   => $instance['latest_title'],
                'orderby' => 'latest',
            );
        }

        if ( $instance['comment_title'] ) {
            $tab_args[] = array(
                'label'   => $instance['comment_title'],
                'orderby' => 'most_comment',
            );
        }
        ?>

    <div class="widget-content">
        <div class="kopa-tabs">
            <ul>
                <?php foreach ( $tab_args as $k => $tab_arg ):?>
                <li><a href="#tabs-1<?php echo $this->number . '-'.$k; ?>"><?php echo $tab_arg['label']; ?></a></li>
                <?php endforeach; ?>
            </ul>

            <?php foreach ( $tab_args as $k1 => $tab_arg ):
            $query_args['orderby'] = $tab_arg['orderby'];
            if (isset($instance['kopa_timestamp'])){
                $query_args['date_query'] = $instance['kopa_timestamp'];
            }
            $posts = kopa_widget_posttype_build_query( $query_args );
            ?>
            <div id="tabs-1<?php echo $this->number . '-'.$k1; ?>">
                <ul class="list-unstyled">
                    <?php while ( $posts->have_posts() ) :
                        $posts->the_post();
                        $post_title = get_the_title();
                    ?>
                    <li class="clearfix item-post">
                        <?php if ( has_post_thumbnail() ) : ?>
                        <a href="<?php the_permalink(); ?>" class="post-thumb pull-left img-responsive" title="<?php the_title(); ?>">
                            <?php the_post_thumbnail('kopa-size-14'); ?>
                        </a>
                        <?php endif; ?>
                        <div class="item-right">
                            <?php if (!empty($post_title)) : ?>
                                <h4 class="post-title"><a href="<?php the_permalink(); ?>" title="<?php the_title();?>"><?php the_title(); ?></a></h4>
                            <?php endif; ?>
                            <?php if ( $display_date_meta ) : ?>
                            <div class="kopa-metadata">
                                <?php
                                    if (!empty($post_title)){?>
                                        <span class="kopa-date"><?php the_time( get_option('date_format') );?></span>
                                    <?php } else{?>
                                        <span class="kopa-date"><a href="<?php the_permalink(); ?>" title="<?php _e('Post with no title', kopa_get_domain());?>"><?php the_time( get_option('date_format') );?></a></span>
                                    <?php }
                                ?>

                            </div>
                            <?php endif; ?>
                            <!-- metadata -->
                        </div>
                    </li>
                    <?php endwhile; ?>
                </ul>
            </div>
            <?php endforeach; ?>
        </div>
    </div>
    <?php
        echo $after_widget;
        wp_reset_postdata();
    }

    function form($instance) {
        $defaults = array(
            'title'             => '',
            'number_of_article' => 3,
            'popular_title'     => __( 'POPULAR', kopa_get_domain() ),
            'comment_title'     => __( 'COMMENT', kopa_get_domain() ),
            'latest_title'      => __( 'RECENT', kopa_get_domain() ),
            'display_date_meta' => true,
            'kopa_timestamp' => '',
        );
        $instance = wp_parse_args( (array) $instance, $defaults );
        $title = strip_tags( $instance['title'] );
        $form['number_of_article'] = $instance['number_of_article'];
        $form['popular_title'] = $instance['popular_title'];
        $form['comment_title'] = $instance['comment_title'];
        $form['latest_title'] = $instance['latest_title'];
        $form['display_date_meta'] = $instance['display_date_meta'];
        $form['kopa_timestamp'] = (int) $instance['kopa_timestamp'];
        ?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('number_of_article'); ?>"><?php _e('Number of article:', kopa_get_domain()); ?></label>
        <input class="widefat" type="number" min="1" id="<?php echo $this->get_field_id('number_of_article'); ?>" name="<?php echo $this->get_field_name('number_of_article'); ?>" value="<?php echo esc_attr( $form['number_of_article'] ); ?>">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('popular_title'); ?>"><?php _e('Popular tab title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('popular_title'); ?>" name="<?php echo $this->get_field_name('popular_title'); ?>" type="text" value="<?php echo esc_attr($form['popular_title']); ?>">
        <small><?php _e( 'Leave it <strong>empty</strong> to hide popular tab.', kopa_get_domain() ); ?></small>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('latest_title'); ?>"><?php _e('Latest tab title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('latest_title'); ?>" name="<?php echo $this->get_field_name('latest_title'); ?>" type="text" value="<?php echo esc_attr($form['latest_title']); ?>">
        <small><?php _e( 'Leave it <strong>empty</strong> to hide latest tab.', kopa_get_domain() ); ?></small>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('comment_title'); ?>"><?php _e('Comment tab title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('comment_title'); ?>" name="<?php echo $this->get_field_name('comment_title'); ?>" type="text" value="<?php echo esc_attr($form['comment_title']); ?>">
        <small><?php _e( 'Leave it <strong>empty</strong> to hide comment tab.', kopa_get_domain() ); ?></small>
    </p>

    <p>
        <label for="<?php echo $this->get_field_id( 'display_date_meta' ); ?>"><?php _e( 'Display date metadata', kopa_get_domain() ); ?></label>
        <input type="checkbox" name="<?php echo $this->get_field_name( 'display_date_meta' ); ?>" id="<?php echo $this->get_field_id( 'display_date_meta' ); ?>" <?php checked( $form['display_date_meta'], true ); ?>>
    </p>
    <?php kopa_print_timeago($this->get_field_id('kopa_timestamp'), $this->get_field_name('kopa_timestamp'), $form['kopa_timestamp']); ?>
    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number_of_article'] = (int) $new_instance['number_of_article'];
        // validate number of article
        if ( 0 >= $instance['number_of_article'] ) {
            $instance['number_of_article'] = 5;
        }
        $instance['popular_title'] = strip_tags( $new_instance['popular_title'] );
        $instance['comment_title'] = strip_tags( $new_instance['comment_title'] );
        $instance['latest_title'] = strip_tags( $new_instance['latest_title'] );
        $instance['display_date_meta'] = isset( $new_instance['display_date_meta'] ) ? true : false;
        $instance['kopa_timestamp'] = $new_instance['kopa_timestamp'];

        return $instance;
    }
}


class Kopa_Widget_List_Gallery extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-gallery-widget', 'description' => __('Show list posts (gallery format) of categories', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kp-list-gallery-widget', __('Kopa Widget List Galleries', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'categories' => array(),
            'posts_per_page' => 6,
            'kopa_timestamp' => '',
            'orderby' => 'latest',
            'display_type' => 'small'
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $form['categories'] = $instance['categories'];
        $form['posts_per_page'] = (int) $instance['posts_per_page'];
        $form['kopa_timestamp'] = (int) $instance['kopa_timestamp'];
        $form['display_type'] = $instance['display_type'];
        $form['orderby'] = $instance['orderby'];
        ?>

    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'categories' ); ?>"><?php _e( 'Categories', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'categories' ); ?>" name="<?php echo $this->get_field_name( 'categories' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $categories = get_categories();
            foreach ($categories as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['categories']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <?php kopa_print_timeago($this->get_field_id('kopa_timestamp'), $this->get_field_name('kopa_timestamp'), $form['kopa_timestamp']); ?>
    <p>
        <label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Orderby', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id('orderby' ); ?>">
            <?php $orderby = array(
            'latest'      => __('Latest', kopa_get_domain()),
            'popular'      => __('Popular by view count', kopa_get_domain()),
            'most_comment' => __('Popular by comment count', kopa_get_domain()),
            'random'       => __('Random', kopa_get_domain())
        );

            foreach ($orderby as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['orderby']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('posts_per_page'); ?>"><?php _e('Number of items:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('posts_per_page'); ?>" name="<?php echo $this->get_field_name('posts_per_page'); ?>" value="<?php echo $form['posts_per_page']; ?>" type="number" min="1">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'display_type' ); ?>"><?php _e( 'Display type', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'display_type' ); ?>" id="<?php echo $this->get_field_id('display_type' ); ?>">
            <?php $typedisplay = array(
            'medium'      => __('Grid layout with medium thumbnail', kopa_get_domain()),
            'small' => __('Grid layout with small thumbnail', kopa_get_domain()),
        );

            foreach ($typedisplay as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['display_type']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>

    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['categories'] = (empty($new_instance['categories'])) ? array() : array_filter($new_instance['categories']);
        $instance['posts_per_page'] = (int) $new_instance['posts_per_page'];
        $instance['kopa_timestamp'] = $new_instance['kopa_timestamp'];
        $instance['display_type'] = $new_instance['display_type'];
        $instance['orderby'] = $new_instance['orderby'];
        return $instance;
    }

    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
        $args['categories'] = $instance['categories'];
        $args['posts_per_page'] = (int) $instance['posts_per_page'];
        $args['post_format'] = 'post-format-gallery';
        $type = $instance['display_type'];
        if (isset($instance['kopa_timestamp'])){
            $args['date_query'] = $instance['kopa_timestamp'];
        }
        $posts = kopa_widget_posttype_build_query($args);

        ?>
    <?php if ( 'small' === $type) : ?>
        <div class="widget kopa-gallery-widget">
            <header class="widget-header">
                <h3 class="widget-title"><?php echo $title; ?></h3>
                <i class="fa fa-plus-square-o"></i>
            </header>
            <div class="widget-content">
                <?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
                <?php if ( has_post_thumbnail() ) : ?>
                    <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="imgLiquid"><?php the_post_thumbnail('kopa-size-15'); ?></a>
                    <?php endif; ?>
                <?php endwhile; ?>
            </div>
        </div>
        <?php endif; // gallery with small thumbnail?>

    <?php if ( 'medium' === $type) : ?>
        <div class="widget kopa-list-posts-2-widget">
            <header class="widget-header">
                <h3 class="widget-title"><?php echo $title; ?></h3>
                <i class="fa fa-plus-square-o"></i>
            </header>
            <div class="widget-content clearfix">
                <?php while ( $posts->have_posts()) :
                    $posts->the_post();
                    $post_title = get_the_title();
                ?>
                <div class="item">
                    <div class="post-thumb<?php if ( !has_post_thumbnail() ) echo ' no-post-thumb'; ?>">
                        <?php if ( has_post_thumbnail() ) : ?>
                        <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="img-responsive">
                            <?php the_post_thumbnail('kopa-size-31'); ?>
                        </a>
                        <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="fa fa-picture-o post-format"></a>
                        <?php endif; ?>

                        <?php
                        if ( kopa_check_title_null(get_the_ID()) ){?>
                            <span class="kopa-date"><?php the_time(get_option('date_format')); ?></span>
                            <?php }else{ ?>
                            <span class="kopa-date"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_time(get_option('date_format')); ?></a></span>
                            <?php }
                        ?>
                    </div>
                    <!-- post thumb -->
                    <div class="item-content">
                        <?php if (!empty($post_title)) : ?>
                            <h4 class="post-title">
                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                            </h4>
                        <?php endif; ?>
                    </div>
                    <!-- item content -->
                </div>
                <!-- item -->
                <?php endwhile; ?>
            </div>
        </div>
        <?php endif; //gallery with medium thumbnail ?>

    <?php wp_reset_postdata();
    }
}


/**
 * FeedBurner Subscribe Widget Class
 */
class Kopa_Widget_Feedburner_Subscribe extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-newletter-widget', 'description' => __('Display Feedburner subscription form', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_feedburner_subscribe', __('Kopa Feedburner Subscribe', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget( $args, $instance ) {
        extract( $args );
        //$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
        $feedburner_id = $instance['feedburner_id'];
        $description = $instance['description'];
        $submit_btn_text = ! empty( $instance['submit_btn_text'] ) ? $instance['submit_btn_text'] : __( 'Signup', kopa_get_domain() );
        $placeholder = ! empty( $instance['placeholder'] ) ? $instance['placeholder'] : __( 'Enter your email address ...', kopa_get_domain() );

        echo $before_widget;?>
    <div class="widget-content">
        <form action="http://feedburner.google.com/fb/a/mailverify" method="post" class="form-news-letter" target="popupwindow" onsubmit="window.open('http://feedburner.google.com/fb/a/mailverify?uri=<?php echo $feedburner_id; ?>', 'popupwindow', 'scrollbars=yes,width=550,height=520'); return true;">
            <input type="hidden" value="<?php echo esc_attr( $feedburner_id ); ?>" name="uri">
            <input type="text" onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;" name="email" value="<?php echo $placeholder;?>" class="email" size="40">
            <button type="submit" class="fa fa-envelope"></button>
            <div id="newsletter-response"></div>
            <p><?php echo $description;?></p>
        </form>
    </div>
    <?php
        echo $after_widget;
    }

    function form( $instance ) {
        $defaults = array(
            'title'           => __( 'NEWSLETTER', kopa_get_domain() ) ,
            'feedburner_id'   => '',
            'description'     => '',
            'placeholder'     => __( 'Enter your email', kopa_get_domain() ),
            'submit_btn_text' => __( 'Subscribe', kopa_get_domain() ),
        );
        $instance = wp_parse_args( (array) $instance, $defaults );
        $title = strip_tags( $instance['title'] );
        $form['feedburner_id'] = $instance['feedburner_id'];
        $form['description'] = $instance['description'];
        $form['placeholder'] = $instance['placeholder'];
        $form['submit_btn_text'] = $instance['submit_btn_text'];
        ?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('feedburner_id'); ?>"><?php _e('Feedburner ID', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('feedburner_id'); ?>" name="<?php echo $this->get_field_name('feedburner_id'); ?>" type="text" value="<?php echo esc_attr($form['feedburner_id']); ?>">
        <small><?php _e( 'eg: http://feeds.feedburner.com/<strong>wordpress</strong>', kopa_get_domain() ); ?></small>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php _e( 'Description', kopa_get_domain() ); ?></label>
        <textarea class="widefat" name="<?php echo $this->get_field_name('description') ?>" id="<?php echo $this->get_field_id('description') ?>" rows="5"><?php echo esc_textarea( $form['description'] ); ?></textarea>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('placeholder'); ?>"><?php _e('Email field placeholder:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('placeholder'); ?>" name="<?php echo $this->get_field_name('placeholder'); ?>" type="text" value="<?php echo esc_attr($form['placeholder']); ?>">
    </p>
    <p style="display:none;">
        <label for="<?php echo $this->get_field_id('submit_btn_text'); ?>"><?php _e('Submit button text:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('submit_btn_text'); ?>" name="<?php echo $this->get_field_name('submit_btn_text'); ?>" type="text" value="<?php echo esc_attr($form['submit_btn_text']); ?>">
    </p>
    <?php
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['feedburner_id'] = strip_tags( $new_instance['feedburner_id'] );
        $instance['description'] = strip_tags( $new_instance['description'] );
        $instance['placeholder'] = strip_tags( $new_instance['placeholder'] );
        $instance['submit_btn_text'] = strip_tags( $new_instance['submit_btn_text'] );

        return $instance;
    }
}

/**
 * Mailchimp Subscribe Widget Class
 */
class Kopa_Widget_Mailchimp_Subscribe extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-newletter-widget', 'description' => __('Display mailchimp newsletter subscription form', kopa_get_domain()));
        $control_ops = array('width' => '400', 'height' => 'auto');
        parent::__construct('kopa_widget_mailchimp_subscribe', __('Kopa Mailchimp Subscribe', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget( $args, $instance ) {
        extract( $args );
        $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
        $mailchimp_form_action = $instance['mailchimp_form_action'];
        $mailchimp_enable_popup = $instance['mailchimp_enable_popup'];
        $description = $instance['description'];
        $submit_btn_text = ! empty( $instance['submit_btn_text'] ) ? $instance['submit_btn_text'] : __( 'Subscribe', kopa_get_domain() );
        $placeholder = ! empty( $instance['placeholder'] ) ? $instance['placeholder'] : __( 'Enter your email', kopa_get_domain() );

        echo $before_widget;
        if ( ! empty( $mailchimp_form_action ) ) {
            ?>

        <div class="widget-content">
            <form action="<?php echo esc_url( $mailchimp_form_action ); ?>" method="post" class="form-news-letter" <?php echo $mailchimp_enable_popup ? 'target="_blank"' : ''; ?>>
                <input type="text" onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;" name="email" value="<?php echo $placeholder;?>">
                <button type="submit" class="fa fa-envelope"></button>
                <div id="newsletter-response"></div>
                <p><?php echo $description;?></p>
            </form>
        </div>

        <?php
        } // endif

        echo $after_widget;
    }

    function form( $instance ) {
        $defaults = array(
            'title'                  => __( 'NEWSLETTER', kopa_get_domain() ),
            'mailchimp_form_action'  => '',
            'mailchimp_enable_popup' => false,
            'description'            => '',
            'placeholder'            => __( 'Your email here ...', kopa_get_domain() ),
            'submit_btn_text'        => __( 'Subscribe', kopa_get_domain() ),
        );
        $instance = wp_parse_args( (array) $instance, $defaults );
        $title = strip_tags( $instance['title'] );
        $form['mailchimp_form_action'] = $instance['mailchimp_form_action'];
        $form['mailchimp_enable_popup'] = $instance['mailchimp_enable_popup'];
        $form['description'] = $instance['description'];
        $form['placeholder'] = $instance['placeholder'];
        $form['submit_btn_text'] = $instance['submit_btn_text'];
        ?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('mailchimp_form_action'); ?>"><?php _e('Mailchimp Form Action:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('mailchimp_form_action'); ?>" name="<?php echo $this->get_field_name('mailchimp_form_action'); ?>" type="text" value="<?php echo esc_attr($form['mailchimp_form_action']); ?>">
    </p>
    <p>
        <input type="checkbox" value="true" id="<?php echo $this->get_field_id( 'mailchimp_enable_popup' ); ?>" name="<?php echo $this->get_field_name( 'mailchimp_enable_popup' ); ?>" <?php checked( true, $form['mailchimp_enable_popup'] ); ?>>
        <label for="<?php echo $this->get_field_id( 'mailchimp_enable_popup' ); ?>"><?php _e( 'Enable <strong>evil</strong> popup mode', kopa_get_domain() ); ?></label>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php _e( 'Description', kopa_get_domain() ); ?></label>
        <textarea class="widefat" name="<?php echo $this->get_field_name('description') ?>" id="<?php echo $this->get_field_id('description') ?>" rows="5"><?php echo esc_textarea( $form['description'] ); ?></textarea>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('placeholder'); ?>"><?php _e('Email field placeholder:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('placeholder'); ?>" name="<?php echo $this->get_field_name('placeholder'); ?>" type="text" value="<?php echo esc_attr($form['placeholder']); ?>">
    </p>
    <p style="display: none;">
        <label for="<?php echo $this->get_field_id('submit_btn_text'); ?>"><?php _e('Submit button text:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('submit_btn_text'); ?>" name="<?php echo $this->get_field_name('submit_btn_text'); ?>" type="text" value="<?php echo esc_attr($form['submit_btn_text']); ?>">
    </p>
    <?php
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['mailchimp_form_action'] = $new_instance['mailchimp_form_action'];
        $instance['mailchimp_enable_popup'] = (bool) $new_instance['mailchimp_enable_popup'] ? true : false;
        $instance['description'] = strip_tags( $new_instance['description'] );
        $instance['placeholder'] = strip_tags( $new_instance['placeholder'] );
        $instance['submit_btn_text'] = strip_tags( $new_instance['submit_btn_text'] );

        return $instance;
    }
}

/*
 * Contact Info Widget Class
 */
class Kopa_Widget_Contact_Info extends WP_Widget
{
    function __construct() {
        $widget_ops = array('classname' => 'kopa-contact-widget', 'description' => __('Display contact info', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_contact_info', __('Kopa Contact Info', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget( $args, $instance ) {
        extract( $args );
        //$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
        $des = $instance['des'];
        $gmap = $instance['gmap'];
        $mail = $instance['mail'];
        $phone = $instance['phone'];
        $fax = $instance['fax'];
        $address = $instance['address'];

        echo $before_widget;
        ?>
    <div class="widget-content">
        <div class="row">
            <div class="col-lg-9 col-md-8 col-sm-12 col-xs-12 pull-right">
                <div class="kopa-map">
                    <?php echo $gmap; ?>
                </div>
            </div>
            <div class="col-lg-3 col-md-4 col-sm-12 col-xs-12 pull-left">
                <div class="post-content">
                    <p><?php echo $des; ?></p>
                    <ul class="list-unstyled">
                        <li>
                            <i class="fa fa-envelope"></i>
                            <h5><?php _e('Email:', kopa_get_domain()); ?></h5>
                            <a href="mailto:<?php echo $mail; ?>"><?php echo $mail; ?></a>
                        </li>
                        <li>
                            <i class="fa fa-phone"></i>
                            <h5><?php _e('Phone:', kopa_get_domain()); ?></h5>
                            <span><?php echo $phone; ?></span>
                        </li>
                        <li>
                            <i class="fa fa-print"></i>
                            <h5><?php _e('Fax:', kopa_get_domain()); ?></h5>
                            <span><?php echo $fax; ?></span>
                        </li>
                        <li>
                            <i class="fa fa-phone"></i>
                            <h5><?php _e('Address:', kopa_get_domain()); ?></h5>
                            <span><?php echo $address; ?></span>
                        </li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
    <?php
        echo $after_widget;
    }

    function form( $instance ) {
        $defaults = array(
            'title'                  => __( 'Contact Info', kopa_get_domain() ),
            'des' => '',
            'gmap' => '',
            'mail'  => '',
            'phone' => '',
            'fax'            => '',
            'address'            => '',
        );
        $instance = wp_parse_args( (array) $instance, $defaults );
        $title = strip_tags( $instance['title'] );
        $form['des'] = strip_tags( $instance['des'] );
        $form['gmap'] = $instance['gmap'];
        $form['mail'] = strip_tags($instance['mail']);
        $form['phone'] = strip_tags ($instance['phone']);
        $form['fax'] = strip_tags($instance['fax']);
        $form['address'] = strip_tags($instance['address']);
        ?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('des'); ?>"><?php _e('Description:', kopa_get_domain()); ?></label>
        <textarea class="widefat" id="<?php echo $this->get_field_id('des'); ?>" name="<?php echo $this->get_field_name('des'); ?>"><?php echo esc_attr($form['des']); ?></textarea>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('gmap'); ?>"><?php _e('Gmap Iframe:', kopa_get_domain()); ?></label>
        <textarea class="widefat" id="<?php echo $this->get_field_id('gmap'); ?>" name="<?php echo $this->get_field_name('gmap'); ?>"><?php echo esc_attr($form['gmap']); ?></textarea>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('mail'); ?>"><?php _e('Email:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('mail'); ?>" name="<?php echo $this->get_field_name('mail'); ?>" type="text" value="<?php echo esc_attr($form['mail']); ?>">
    </p>

    <p>
        <label for="<?php echo $this->get_field_id('phone'); ?>"><?php _e('Phone:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('phone'); ?>" name="<?php echo $this->get_field_name('phone'); ?>" type="text" value="<?php echo esc_attr($form['phone']); ?>">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('fax'); ?>"><?php _e('Fax:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('fax'); ?>" name="<?php echo $this->get_field_name('fax'); ?>" type="text" value="<?php echo esc_attr($form['fax']); ?>">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('address'); ?>"><?php _e('Address:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('address'); ?>" name="<?php echo $this->get_field_name('address'); ?>" type="text" value="<?php echo esc_attr($form['address']); ?>">
    </p>
    <?php
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['des'] = strip_tags( $new_instance['des'] );
        $instance['gmap'] = $new_instance['gmap'];
        $instance['mail'] = strip_tags( $new_instance['mail'] );
        $instance['phone'] = strip_tags( $new_instance['phone'] );
        $instance['fax'] = strip_tags( $new_instance['fax'] );
        $instance['address'] = strip_tags( $new_instance['address'] );
        return $instance;
    }
}

/**
 * Kopa Widget Article Single
 */
class Kopa_Widget_Article_Single extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-single-post-widget', 'description' => __('Display first article of blog by specific conditions', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_article_single', __('Kopa Widget Article Single', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'categories' => array(),
            'kopa_timestamp' => '',
            'orderby' => 'latest',
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $form['kopa_timestamp'] = (int) $instance['kopa_timestamp'];
        $form['categories'] = $instance['categories'];
        $form['orderby'] = $instance['orderby'];
        ?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'categories' ); ?>"><?php _e( 'Categories', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'categories' ); ?>" name="<?php echo $this->get_field_name( 'categories' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $categories = get_categories();
            foreach ($categories as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['categories']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <?php kopa_print_timeago($this->get_field_id('kopa_timestamp'), $this->get_field_name('kopa_timestamp'), $form['kopa_timestamp']); ?>
    <p>
        <label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Get article by:', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id('orderby' ); ?>">
            <?php $orderby = array(
            'latest'      => __('Latest article', kopa_get_domain()),
            'popular'      => __('Article by view count', kopa_get_domain()),
            'most_comment' => __('Article by comment count', kopa_get_domain()),
            'random'       => __('Article random', kopa_get_domain())
        );

            foreach ($orderby as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['orderby']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['categories'] = (empty($new_instance['categories'])) ? array() : array_filter($new_instance['categories']);
        $instance['orderby'] = $new_instance['orderby'];
        $instance['kopa_timestamp'] = $new_instance['kopa_timestamp'];
        return $instance;
    }

    function widget($args, $instance) {
        extract($args);
        $query_args['categories'] = $instance['categories'];
        $query_args['orderby'] = $instance['orderby'];
        $query_args['posts_per_page'] = 1;
        if (isset($instance['kopa_timestamp'])){
            $query_args['date_query'] = $instance['kopa_timestamp'];
        }
        $posts = kopa_widget_posttype_build_query($query_args);
        echo $before_widget;

        while ( $posts->have_posts() ) : $posts->the_post();?>

        <div class="widget-content">
            <div class="item">
                <div class="post-thumb">
                    <?php if ( has_post_thumbnail() ) : ?>
                    <a href="<?php the_permalink(); ?>" class="img-responsive" title="<?php the_title();?>"><?php the_post_thumbnail('kopa-size-01'); ?></a>
                    <?php endif; ?>
                </div>
                <!-- post thumb -->
                <div class="kopa-metadata">
                    <span class="kopa-date"><?php the_time( get_option('date_format') ); ?></span>
                </div>
                <!-- metadata -->
                <div class="item-content">
                    <h4 class="post-title"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title();?></a></h4>
                    <div class="post-content">
                        <?php the_excerpt(); ?>
                    </div>
                </div>
            </div>
            <!-- item -->
        </div>

        <?php endwhile; ?>

    <?php wp_reset_postdata();
        echo $after_widget;
    }
}

/**
 * Kopa widget Social shared
 */
class Kopa_Widget_Social_Share extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-social-3-widget', 'description' => __('Display social share links', kopa_get_domain()));
        $control_ops = array('width' => '500px', 'height' => 'auto');
        parent::__construct('kopa_widget_social_share', __('Kopa Widget Social Share', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'type' => 'circular_icon',
            'use_theme_social'=> 'true'
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);

        $rss_url = strip_tags(isset($instance['rss_url']) ? $instance['rss_url'] : '');
        $facebook_url = strip_tags(isset($instance['facebook_url']) ? $instance['facebook_url'] : '');
        $twitter_url = strip_tags(isset($instance['twitter_url']) ? $instance['twitter_url'] : '');
        $gplus_url = strip_tags(isset($instance['gplus_url']) ? $instance['gplus_url'] : '');
        $dribble_url = strip_tags(isset($instance['dribble_url']) ? $instance['dribble_url'] : '');
        $linkedin_url = strip_tags(isset($instance['linkedin_url']) ? $instance['linkedin_url'] : '');
        $skype_url = strip_tags(isset($instance['skype_url']) ? $instance['skype_url'] : '');
        $tumblr_url = strip_tags(isset($instance['tumblr_url']) ? $instance['tumblr_url'] : '');
        $pinterest_url = strip_tags(isset($instance['pinterest_url']) ? $instance['pinterest_url'] : '');
        $youtube_url = strip_tags(isset($instance['youtube_url']) ? $instance['youtube_url'] : '');

        $social_link_target = isset($instance['social_link_target']) ? $instance['social_link_target'] : '_self';
        $form['use_theme_social'] = $instance['use_theme_social'];
        $form['type'] = $instance['type'];


        ?>
    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e( 'Type', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'type' ); ?>" id="<?php echo $this->get_field_id('type'); ?>">
            <?php $typedisplay = array(
            'circular_icon'      => __('Circular icons', kopa_get_domain()),
            'square_icon'      => __('Quare icons', kopa_get_domain()),
            'rectangular_icon'      => __('Rectangular icons', kopa_get_domain()),
        );

            foreach ($typedisplay as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['type']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <input id="<?php echo $this->get_field_id('use_theme_social'); ?>" name="<?php echo $this->get_field_name('use_theme_social'); ?>" type="checkbox" value="true" <?php echo ('true' === $form['use_theme_social']) ? 'checked="checked"' : ''; ?>  onchange="show_on_check_social_link(this);" data-wrapper="<?php echo $this->id; ?>"/>
        <label for="<?php echo $this->get_field_id('use_theme_social'); ?>"><?php _e('Use settings from theme option', kopa_get_domain()); ?></label>
    </p>
    <div class="social-link-wrapper" id="<?php echo $this->id;?>">
        <p><?php _e('Or use other social links below:', kopa_get_domain()); ?></p>
        <p>
            <label for="<?php echo $this->get_field_id('rss_url'); ?>"><?php _e('Rss Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('rss_url'); ?>" name="<?php echo $this->get_field_name('rss_url'); ?>" type="text" value="<?php echo esc_attr($rss_url); ?>">
            <small><?php _e('Display the RSS feed button with the default RSS feed or enter a custom feed below. Enter "HIDE" if you want to hide it', kopa_get_domain()); ?></small>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('facebook_url'); ?>"><?php _e('Facebook Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('facebook_url'); ?>" name="<?php echo $this->get_field_name('facebook_url'); ?>" type="text" value="<?php echo esc_attr($facebook_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('twitter_url'); ?>"><?php _e('Twitter Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('twitter_url'); ?>" name="<?php echo $this->get_field_name('twitter_url'); ?>" type="text" value="<?php echo esc_attr($twitter_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('gplus_url'); ?>"><?php _e('Google Plus Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('gplus_url'); ?>" name="<?php echo $this->get_field_name('gplus_url'); ?>" type="text" value="<?php echo esc_attr($gplus_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('dribble_url'); ?>"><?php _e('Dribble Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('dribble_url'); ?>" name="<?php echo $this->get_field_name('dribble_url'); ?>" type="text" value="<?php echo esc_attr($dribble_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('linkedin_url'); ?>"><?php _e('Linkedin Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('linkedin_url'); ?>" name="<?php echo $this->get_field_name('linkedin_url'); ?>" type="text" value="<?php echo esc_attr($linkedin_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('skype_url'); ?>"><?php _e('Skype Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('skype_url'); ?>" name="<?php echo $this->get_field_name('skype_url'); ?>" type="text" value="<?php echo esc_attr($skype_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('tumblr_url'); ?>"><?php _e('Tumblr Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('tumblr_url'); ?>" name="<?php echo $this->get_field_name('tumblr_url'); ?>" type="text" value="<?php echo esc_attr($tumblr_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('pinterest_url'); ?>"><?php _e('Pinterest Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('pinterest_url'); ?>" name="<?php echo $this->get_field_name('pinterest_url'); ?>" type="text" value="<?php echo esc_attr($pinterest_url); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('youtube_url'); ?>"><?php _e('Youtube Url:', kopa_get_domain()); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('youtube_url'); ?>" name="<?php echo $this->get_field_name('youtube_url'); ?>" type="text" value="<?php echo esc_attr($youtube_url); ?>">
        </p>
        <p><?php _e('Social Links Target:', kopa_get_domain());?></p>
        <p>
            <select class="widefat" name="<?php echo $this->get_field_name('social_link_target'); ?>">
                <option value="_blank" <?php if ('_blank' === $social_link_target ) echo 'selected'; ?>>Opens in a new window or tab</option>
                <option value="_self" <?php if ('_self' === $social_link_target ) echo 'selected'; ?>>Opens in the same frame</option>
            </select>
        </p>
    </div>
    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['use_theme_social'] = isset($new_instance['use_theme_social']) ? $new_instance['use_theme_social'] : 'false';
        $instance['type'] = $new_instance['type'];
        $instance['rss_url'] = strip_tags($new_instance['rss_url']);
        $instance['facebook_url'] = strip_tags($new_instance['facebook_url']);
        $instance['twitter_url'] = strip_tags($new_instance['twitter_url']);
        $instance['gplus_url'] = strip_tags($new_instance['gplus_url']);
        $instance['dribble_url'] = strip_tags($new_instance['dribble_url']);
        $instance['linkedin_url'] = strip_tags($new_instance['linkedin_url']);
        $instance['skype_url'] = strip_tags($new_instance['skype_url']);
        $instance['tumblr_url'] = strip_tags($new_instance['tumblr_url']);
        $instance['pinterest_url'] = strip_tags($new_instance['pinterest_url']);
        $instance['youtube_url'] = strip_tags($new_instance['youtube_url']);
        $instance['social_link_target'] = $new_instance['social_link_target'];
        return $instance;
    }

    function widget($args, $instance) {
        extract($args);

        $use_theme_setting = 'true' === $instance['use_theme_social'] ? true : false;
        $type = $instance['type'];

        if( $use_theme_setting ){
            $target = kopa_get_option('kopa_theme_options_social_link_target');
            $rss_url = kopa_get_option ( 'kopa_theme_options_social_links_rss_url' );
            $facebook_url = kopa_get_option ( 'kopa_theme_options_social_links_facebook_url' );
            $twitter_url = kopa_get_option ( 'kopa_theme_options_social_links_twitter_url' );
            $gplus_url = kopa_get_option ( 'kopa_theme_options_social_links_gplus_url' );
            $skype_url = kopa_get_option ( 'kopa_theme_options_social_links_skype_url' );
            $dribbble_url = kopa_get_option ( 'kopa_theme_options_social_links_dribbble_url') ;
            $tumblr_url = kopa_get_option ( 'kopa_theme_options_social_links_tumblr_url' );
            $pinterest_url = kopa_get_option ( 'kopa_theme_options_social_links_pinterest_url' );
            $linkedin_url = kopa_get_option ( 'kopa_theme_options_social_links_linkedin_url' );
            $youtube_url = kopa_get_option ( 'kopa_theme_options_social_links_youtube_url' );
        }else{
            $target = $instance['social_link_target'];
            $rss_url = $instance['rss_url'];
            $facebook_url = $instance['facebook_url'];
            $twitter_url = $instance['twitter_url'];
            $gplus_url = $instance['gplus_url'];
            $skype_url = $instance['skype_url'];
            $dribbble_url = $instance['dribble_url'];
            $tumblr_url = $instance['tumblr_url'];
            $pinterest_url = $instance['pinterest_url'];
            $linkedin_url = $instance['linkedin_url'];
            $youtube_url = $instance['youtube_url'];
        }
        if (empty($rss_url)){
            $rss_url = get_bloginfo('rss2_url');
        }

        switch ($type) {
            case 'square_icon':
                $social_class = 'link-social-1';
                $social_widget_class= 'widget kopa-social-widget';
                break;
            case 'rectangular_icon':
                $social_class = 'link-social-2';
                $social_widget_class= 'widget kopa-social-2-widget';
                break;
            default:
                $social_class = 'kopa-social clearfix';
                $social_widget_class= 'widget kopa-social-3-widget';
                break;
        }

        $SociaArr = array(
            'rss' => array(
                'url' => $rss_url,
                'title' => __('Rss', kopa_get_domain())
            ),
            'facebook' => array(
                'url' => $facebook_url,
                'title' => __('Facebook', kopa_get_domain())
            ),
            'twitter' => array(
                'url' => $twitter_url,
                'title' => __('Twitter', kopa_get_domain())
            ),
            'google-plus' => array(
                'url' => $gplus_url,
                'title' => __('Google+', kopa_get_domain())
            ),
            'skype' => array(
                'url' => $skype_url,
                'title' => __('Skype', kopa_get_domain())
            ),
            'dribbble' => array(
                'url' => $dribbble_url,
                'title' => __('Dribbble', kopa_get_domain())
            ),
            'tumblr' => array(
                'url' => $tumblr_url,
                'title' => __('Tumblr', kopa_get_domain())
            ),
            'pinterest-square' => array(
                'url' => $pinterest_url,
                'title' => __('Pinterest', kopa_get_domain())
            ),
            'linkedin' => array(
                'url' => $linkedin_url,
                'title' => __('Linkedin', kopa_get_domain())
            ),
            'youtube' => array(
                'url' => $youtube_url,
                'title' => __('Youtube', kopa_get_domain())
            )
        );

        ?>
    <div class="<?php echo $social_widget_class;?>">
        <div class="widget-content">
            <div class="<?php echo $social_class;?>">

                <?php foreach ( $SociaArr as $k => $v ) : ?>
                <?php
                if ( 'rss' === $k ) {
                    if ($v['url'] === 'HIDE'){
                        continue;
                    }
                }elseif(empty($v['url'])){
                    continue;
                }
                elseif ( 'square_icon' === $type ){?>
                    <a href="<?php echo esc_url($v['url']); ?>" target="<?php echo $target; ?>" title="<?php echo $v['title'];?>" rel="nofollow"><i class="fa fa-<?php echo $k;?>"></i></a>
                    <?php } elseif ( 'rectangular_icon' === $type ) {  ?>
                    <a href="<?php echo esc_url($v['url']); ?>" target="<?php echo $target; ?>" title="<?php echo $v['title'];?>" rel="nofollow"><i class="fa fa-<?php echo $k;?>"></i><?php echo $v['title']; ?></a>
                    <?php } else {  ?>
                    <a href="<?php echo esc_url($v['url']); ?>" class="fa fa-<?php echo $k;?>" target="<?php echo $target; ?>" title="<?php echo  $v['title']; ?>" rel="nofollow"></a>
                    <?php }
                ?>
                <?php endforeach; ?>
            </div>
            <!-- social -->
        </div>
    </div>
    <?php

    }
}

/*
 * Kopa widget video
 */
class Kopa_Widget_Video extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-media-widget', 'description' => __('video list widget', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_video', __('Kopa Widget List Video', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);

        $query_args['categories'] = $instance['categories'];
        $query_args['relation'] = esc_attr($instance['relation']);
        if (isset($instance['kopa_timestamp'])){
            $query_args['date_query'] = $instance['kopa_timestamp'];
        }

        $query_args['post_format'] = 'post-format-video';
        $query_args['posts_per_page'] = (int) $instance['posts_per_page'];
        $query_args['orderby'] = $instance['orderby'];

        $type = $instance['display_type'];

        $posts = kopa_widget_posttype_build_query($query_args);
        ?>

    <?php if ( 'list_video' === $type)  : ?>
        <div class="widget kopa-media-widget">
            <header class="widget-header">
                <h3 class="widget-title"><?php echo $title; ?></h3>
                <i class="fa fa-plus-square-o"></i>
            </header>

            <div class="widget-content">
                <?php $count = 0; ?>
                <?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
                    <div class="item-post">
                        <h4 class="post-title"><a href="<?php the_permalink(); ?>"><i class="fa fa-youtube-play"></i><?php the_title(); ?></a></h4>
                    </div>
                    <!-- item-post -->
                <?php endwhile; ?>

            </div>
        </div>
        <?php endif; //list video ?>

    <?php if ( 'grid_video' === $type ) : ?>
        <div class="widget kopa-list-posts-2-widget">
            <header class="widget-header">
                <h3 class="widget-title"><?php echo $title; ?></h3>
                <i class="fa fa-plus-square-o"></i>
            </header>
            <div class="widget-content clearfix">
                <?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
                <div class="item">
                    <div class="post-thumb<?php if ( !has_post_thumbnail() ) echo ' no-post-thumb'; ?>">
                        <?php if ( has_post_thumbnail() ) : ?>
                        <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="img-responsive">
                            <?php the_post_thumbnail('kopa-size-31'); ?>
                        </a>
                        <a href="<?php the_permalink(); ?>" class="fa fa-play post-format" title="<?php the_title(); ?>"></a>
                        <?php endif; ?>

                        <?php if ( kopa_check_title_null(get_the_ID())){?>
                        <span class="kopa-date"><?php the_time(get_option('date_format')); ?></span>
                        <?php }else{ ?>
                        <span class="kopa-date"><a href="<?php the_permalink();?>" title="<?php the_title(); ?>"><?php the_time(get_option('date_format')); ?></a></span>
                        <?php }
                        ?>

                    </div>
                    <!-- post thumb -->
                    <div class="item-content">
                        <h4 class="post-title">
                            <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title();?></a>
                        </h4>
                    </div>
                    <!-- item content -->
                </div>
                <!-- item -->
                <?php endwhile; ?>
            </div>
        </div>
        <?php endif; //grid video ?>


    <?php
        wp_reset_postdata();
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'categories' => array(),
            'relation' => 'OR',
            'tags' => array(),
            'kopa_timestamp' => '',
            'posts_per_page' => 6,
            'orderby' => 'latest',
            'display_type' => 'medium'
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $form['categories'] = $instance['categories'];
        $form['relation'] = esc_attr($instance['relation']);
        $form['tags'] = $instance['tags'];
        $form['kopa_timestamp'] = $instance['kopa_timestamp'];
        $form['posts_per_page'] = (int) $instance['posts_per_page'];
        $form['orderby'] = $instance['orderby'];
        $form['display_type'] = $instance['display_type'];
        ?>

    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'categories' ); ?>"><?php _e( 'Categories', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'categories' ); ?>" name="<?php echo $this->get_field_name( 'categories' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $categories = get_categories();
            foreach ($categories as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['categories']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('relation'); ?>"><?php _e('Relation', kopa_get_domain()); ?>:</label>
        <select class="widefat" name="<?php echo $this->get_field_name('relation'); ?>" id="<?php echo $this->get_field_id('relation'); ?>">
            <option value="OR" <?php selected('OR', $form['relation']); ?>><?php _e('OR', kopa_get_domain()); ?></option>
            <option value="AND" <?php selected('AND', $form['relation']); ?>><?php _e('AND', kopa_get_domain()); ?></option>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'tags' ); ?>"><?php _e( 'Tags', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'tags' ); ?>" name="<?php echo $this->get_field_name( 'tags' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $tags = get_tags();
            foreach ($tags as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['tags']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <?php kopa_print_timeago($this->get_field_id('kopa_timestamp'), $this->get_field_name('kopa_timestamp'), $form['kopa_timestamp']); ?>
    <p>
        <label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Orderby', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id('orderby' ); ?>">
            <?php $orderby = array(
            'latest'      => __('Latest', kopa_get_domain()),
            'popular'      => __('Popular by view count', kopa_get_domain()),
            'most_comment' => __('Popular by comment count', kopa_get_domain()),
            'random'       => __('Random', kopa_get_domain())
        );

            foreach ($orderby as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['orderby']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('posts_per_page'); ?>"><?php _e('Number of items:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('posts_per_page'); ?>" name="<?php echo $this->get_field_name('posts_per_page'); ?>" value="<?php echo $form['posts_per_page']; ?>" type="number" min="1">
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'display_type' ); ?>"><?php _e( 'Display type', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'display_type' ); ?>" id="<?php echo $this->get_field_id('display_type' ); ?>">
            <?php $typedisplay = array(
            'list_video'      => __('List videos', kopa_get_domain()),
            'grid_video'      => __('Grid videos', kopa_get_domain()),
        );

            foreach ($typedisplay as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['display_type']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>

    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['categories'] = (empty($new_instance['categories'])) ? array() : array_filter($new_instance['categories']);
        $instance['relation'] = $new_instance['relation'];
        $instance['tags'] = (empty($new_instance['tags'])) ? array() : array_filter($new_instance['tags']);
        $instance['kopa_timestamp'] = $new_instance['kopa_timestamp'];
        $instance['posts_per_page'] = (int) $new_instance['posts_per_page'];
        $instance['orderby'] = $new_instance['orderby'];
        $instance['display_type'] = $new_instance['display_type'];
        return $instance;
    }
}

/*
 * Kopa widget audio
 */
class Kopa_Widget_Audio extends WP_Widget {
    function __construct() {
        $widget_ops = array('classname' => 'kopa-list-posts-2-widget', 'description' => __('audio list widget', kopa_get_domain()));
        $control_ops = array('width' => 'auto', 'height' => 'auto');
        parent::__construct('kopa_widget_audio', __('Kopa Widget List Audio', kopa_get_domain()), $widget_ops, $control_ops);
    }

    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);

        $query_args['categories'] = $instance['categories'];
        $query_args['relation'] = esc_attr($instance['relation']);
        if (isset($instance['kopa_timestamp'])){
            $query_args['date_query'] = $instance['kopa_timestamp'];
        }

        $query_args['post_format'] = 'post-format-audio';
        $query_args['posts_per_page'] = (int) $instance['posts_per_page'];
        $query_args['orderby'] = $instance['orderby'];
        $posts = kopa_widget_posttype_build_query($query_args);
        echo $before_widget;
        ?>

    <header class="widget-header">
        <h3 class="widget-title"><?php echo $title; ?></h3>
        <i class="fa fa-plus-square-o"></i>
    </header>

    <div class="widget-content clearfix">
        <?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

        <div class="item">
            <div class="post-thumb<?php if (!has_post_thumbnail()) echo ' no-post-thumb'; ?>">
                <?php if ( has_post_thumbnail() ) : ?>
                <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="img-responsive">
                    <?php the_post_thumbnail('kopa-size-31'); ?>
                </a>

                <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="fa fa-volume-down post-format"></a>
                <?php endif; ?>
                <?php
                if ( kopa_check_title_null(get_the_ID()) ){?>
                    <span class="kopa-date"><?php the_time(get_option('date_format')); ?></span>
                    <?php }else{ ?>
                    <span class="kopa-date"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_time(get_option('date_format')); ?></a></span>
                    <?php }
                ?>

            </div>
            <!-- post thumb -->
            <div class="item-content">
                <h4 class="post-title">
                    <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a>
                </h4>
            </div>
            <!-- item content -->
        </div>
        <!-- item -->
        <?php endwhile; ?>
    </div>


    <?php
        echo $after_widget;
        wp_reset_postdata();
    }

    function form($instance) {
        $default = array(
            'title' => '',
            'categories' => array(),
            'relation' => 'OR',
            'tags' => array(),
            'kopa_timestamp' => '',
            'posts_per_page' => 6,
            'orderby' => 'latest',
        );
        $instance = wp_parse_args((array) $instance, $default);
        $title = strip_tags($instance['title']);
        $form['categories'] = $instance['categories'];
        $form['relation'] = esc_attr($instance['relation']);
        $form['tags'] = $instance['tags'];
        $form['kopa_timestamp'] = $instance['kopa_timestamp'];
        $form['posts_per_page'] = (int) $instance['posts_per_page'];
        $form['orderby'] = $instance['orderby'];
        ?>

    <p>
        <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'categories' ); ?>"><?php _e( 'Categories', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'categories' ); ?>" name="<?php echo $this->get_field_name( 'categories' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $categories = get_categories();
            foreach ($categories as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['categories']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('relation'); ?>"><?php _e('Relation', kopa_get_domain()); ?>:</label>
        <select class="widefat" name="<?php echo $this->get_field_name('relation'); ?>" id="<?php echo $this->get_field_id('relation'); ?>">
            <option value="OR" <?php selected('OR', $form['relation']); ?>><?php _e('OR', kopa_get_domain()); ?></option>
            <option value="AND" <?php selected('AND', $form['relation']); ?>><?php _e('AND', kopa_get_domain()); ?></option>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id( 'tags' ); ?>"><?php _e( 'Tags', kopa_get_domain() ); ?></label>
        <select class="widefat" id="<?php echo $this->get_field_id( 'tags' ); ?>" name="<?php echo $this->get_field_name( 'tags' ) ?>[]" multiple="multiple" size="5">
            <option value=""><?php _e('--Select--', kopa_get_domain()); ?></option>
            <?php
            $tags = get_tags();
            foreach ($tags as $category) :
                ?>
                <option value="<?php echo $category->term_id; ?>" <?php echo in_array($category->term_id, $form['tags']) ? 'selected="selected"' : ''; ?>>
                    <?php echo $category->name.' ('.$category->count.')'; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <?php kopa_print_timeago($this->get_field_id('kopa_timestamp'), $this->get_field_name('kopa_timestamp'), $form['kopa_timestamp']); ?>
    <p>
        <label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Orderby', kopa_get_domain() ); ?></label>
        <select class="widefat" name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id('orderby' ); ?>">
            <?php $orderby = array(
            'latest'      => __('Latest', kopa_get_domain()),
            'popular'      => __('Popular by view count', kopa_get_domain()),
            'most_comment' => __('Popular by comment count', kopa_get_domain()),
            'random'       => __('Random', kopa_get_domain())
        );

            foreach ($orderby as $value => $label) :
                ?>
                <option value="<?php echo $value; ?>" <?php selected($value, $form['orderby']); ?>><?php echo $label; ?></option>
                <?php
            endforeach;
            ?>
        </select>
    </p>
    <p>
        <label for="<?php echo $this->get_field_id('posts_per_page'); ?>"><?php _e('Number of items:', kopa_get_domain()); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id('posts_per_page'); ?>" name="<?php echo $this->get_field_name('posts_per_page'); ?>" value="<?php echo $form['posts_per_page']; ?>" type="number" min="1">
    </p>

    <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['categories'] = (empty($new_instance['categories'])) ? array() : array_filter($new_instance['categories']);
        $instance['relation'] = $new_instance['relation'];
        $instance['tags'] = (empty($new_instance['tags'])) ? array() : array_filter($new_instance['tags']);
        $instance['kopa_timestamp'] = $new_instance['kopa_timestamp'];
        $instance['posts_per_page'] = (int) $new_instance['posts_per_page'];
        $instance['orderby'] = $new_instance['orderby'];
        return $instance;
    }
}